@@ -37,40 +37,40 @@ func TestEntries(t *testing.T) {
 		t.Parallel()
 		t.Run("works with correctly comparable types", func(t *testing.T) {
 			t.Parallel()
-			entries := list.Entries[configdomain.HostingPlatform]{
+			entries := list.Entries[configdomain.ForgeType]{
 				{
-					Data: configdomain.HostingPlatformGitHub,
+					Data: configdomain.ForgeTypeGitHub,
 					Text: "Github",
 				},
 				{
-					Data: configdomain.HostingPlatformGitLab,
+					Data: configdomain.ForgeTypeGitLab,
 					Text: "GitLab",
 				},
 			}
-			have := entries.IndexOf(configdomain.HostingPlatformGitLab)
+			have := entries.IndexOf(configdomain.ForgeTypeGitLab)
 			want := 1
 			must.EqOp(t, want, have)
 		})
 		t.Run("does not work with options", func(t *testing.T) {
 			t.Parallel()
-			entries := list.Entries[Option[configdomain.HostingPlatform]]{
+			entries := list.Entries[Option[configdomain.ForgeType]]{
 				{
-					Data: None[configdomain.HostingPlatform](),
+					Data: None[configdomain.ForgeType](),
 					Text: "auto-detect",
 				},
 				{
-					Data: Some(configdomain.HostingPlatformGitHub),
+					Data: Some(configdomain.ForgeTypeGitHub),
 					Text: "Github",
 				},
 				{
-					Data: Some(configdomain.HostingPlatformGitLab),
+					Data: Some(configdomain.ForgeTypeGitLab),
 					Text: "GitLab",
 				},
 			}
-			have := entries.IndexOf(Some(configdomain.HostingPlatformGitHub))
+			have := entries.IndexOf(Some(configdomain.ForgeTypeGitHub))
 			want := 0 // this should be 1 if comparing options would work
 			must.EqOp(t, want, have)
-			have = entries.IndexOfFunc(Some(configdomain.HostingPlatformGitHub), func(a, b Option[configdomain.HostingPlatform]) bool {
+			have = entries.IndexOfFunc(Some(configdomain.ForgeTypeGitHub), func(a, b Option[configdomain.ForgeType]) bool {
 				return a.Equal(b)
 			})
 			want = 1
@@ -82,21 +82,21 @@ func TestEntries(t *testing.T) {
 		t.Parallel()
 		t.Run("works with options", func(t *testing.T) {
 			t.Parallel()
-			entries := list.Entries[Option[configdomain.HostingPlatform]]{
+			entries := list.Entries[Option[configdomain.ForgeType]]{
 				{
-					Data: None[configdomain.HostingPlatform](),
+					Data: None[configdomain.ForgeType](),
 					Text: "auto-detect",
 				},
 				{
-					Data: Some(configdomain.HostingPlatformGitHub),
+					Data: Some(configdomain.ForgeTypeGitHub),
 					Text: "Github",
 				},
 				{
-					Data: Some(configdomain.HostingPlatformGitLab),
+					Data: Some(configdomain.ForgeTypeGitLab),
 					Text: "GitLab",
 				},
 			}
-			have := entries.IndexOfFunc(Some(configdomain.HostingPlatformGitHub), func(a, b Option[configdomain.HostingPlatform]) bool {
+			have := entries.IndexOfFunc(Some(configdomain.ForgeTypeGitHub), func(a, b Option[configdomain.ForgeType]) bool {
 				return a.Equal(b)
 			})
 			want := 1
