@@ -4,13 +4,13 @@ import (
 	"strings"
 
 	tea "github.com/charmbracelet/bubbletea"
-	"github.com/git-town/git-town/v17/internal/cli/colors"
-	"github.com/git-town/git-town/v17/internal/cli/dialog/components"
-	"github.com/git-town/git-town/v17/internal/cli/dialog/components/list"
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/gohacks/slice"
-	"github.com/git-town/git-town/v17/internal/messages"
+	"github.com/git-town/git-town/v18/internal/cli/colors"
+	"github.com/git-town/git-town/v18/internal/cli/dialog/components"
+	"github.com/git-town/git-town/v18/internal/cli/dialog/components/list"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/gohacks/slice"
+	"github.com/git-town/git-town/v18/internal/messages"
 	"github.com/muesli/termenv"
 )
 
@@ -63,7 +63,7 @@ func (self SwitchModel) View() string {
 	if self.UncommittedChanges {
 		s.WriteString("\n")
 		s.WriteString(colors.BoldCyan().Styled(messages.SwitchUncommittedChanges))
-		s.WriteString("\n")
+		s.WriteString("\n\n")
 	}
 	window := slice.Window(slice.WindowArgs{
 		CursorPos:    self.Cursor,
@@ -167,7 +167,7 @@ func SwitchBranch(entries []SwitchBranchEntry, cursor int, uncommittedChanges bo
 	if err != nil {
 		return "", false, err
 	}
-	result := dialogResult.(SwitchModel) //nolint:forcetypeassert
+	result := dialogResult.(SwitchModel)
 	selectedData := result.List.SelectedData()
 	return selectedData.Branch, result.Aborted(), nil
 }
@@ -176,9 +176,9 @@ func newSwitchBranchListEntries(switchBranchEntries []SwitchBranchEntry) list.En
 	result := make(list.Entries[SwitchBranchEntry], len(switchBranchEntries))
 	for e, entry := range switchBranchEntries {
 		result[e] = list.Entry[SwitchBranchEntry]{
-			Data:    entry,
-			Enabled: !entry.OtherWorktree,
-			Text:    entry.String(),
+			Data:     entry,
+			Disabled: entry.OtherWorktree,
+			Text:     entry.String(),
 		}
 	}
 	return result
