@@ -12,9 +12,9 @@ import (
 	"github.com/git-town/git-town/v18/internal/config"
 	"github.com/git-town/git-town/v18/internal/config/configdomain"
 	"github.com/git-town/git-town/v18/internal/execute"
+	"github.com/git-town/git-town/v18/internal/forge"
+	"github.com/git-town/git-town/v18/internal/forge/forgedomain"
 	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	"github.com/git-town/git-town/v18/internal/hosting"
-	"github.com/git-town/git-town/v18/internal/hosting/hostingdomain"
 	"github.com/git-town/git-town/v18/internal/messages"
 	"github.com/git-town/git-town/v18/internal/undo/undoconfig"
 	"github.com/git-town/git-town/v18/internal/validate"
@@ -27,21 +27,37 @@ import (
 	"github.com/spf13/cobra"
 )
 
-const compressCommand = "compress"
-
-const compressDesc = "Squash all commits on feature branches down to a single commit"
-
-const compressHelp = `
+const (
+	compressCommand = "compress"
+	compressDesc    = "Squash all commits on the current branch down to a single commit"
+	compressHelp    = `
 Compress is a more convenient way of running "git rebase --interactive"
 and choosing to fixup all commits.
-Branches must be synced before you compress them.
+Branches must be fully synced before you compress them.
 
-By default, this command compresses only the branch you are on.
-With the --stack switch it compresses all branches in the current stack.
+Provide the --stack switch to compress all branches in the stack.
 
 The compressed commit uses the commit message of the first commit in the branch.
 You can provide a custom commit message with the -m switch.
+
+Assuming you have a feature branch with these commits:
+
+$ git log --pretty=format:'%s'
+commit 1
+commit 2
+commit 3
+
+Let's compress these three commits into a single commit:
+
+$ git town compress
+
+Now your branch has a single commit with the name of the first commit but
+containing the changes of all three commits that existed on the branch before:
+
+$ git log --pretty=format:'%s'
+commit 1
 `
+)
 
 func compressCmd() *cobra.Command {
 	addDryRunFlag, readDryRunFlag := flags.DryRun()
@@ -114,7 +130,7 @@ func executeCompress(dryRun configdomain.DryRun, verbose configdomain.Verbose, m
 		Backend:                 repo.Backend,
 		CommandsCounter:         repo.CommandsCounter,
 		Config:                  data.config,
-		Connector:               None[hostingdomain.Connector](),
+		Connector:               None[forgedomain.Connector](),
 		DialogTestInputs:        data.dialogTestInputs,
 		FinalMessages:           repo.FinalMessages,
 		Frontend:                repo.Frontend,
@@ -184,7 +200,7 @@ func determineCompressBranchesData(repo execute.OpenRepoResult, dryRun configdom
 	}
 	localBranches := branchesSnapshot.Branches.LocalBranches().Names()
 	branchesAndTypes := repo.UnvalidatedConfig.UnvalidatedBranchesAndTypes(branchesSnapshot.Branches.LocalBranches().Names())
-	connector, err := hosting.NewConnector(repo.UnvalidatedConfig, repo.UnvalidatedConfig.NormalConfig.DevRemote, print.Logger{})
+	connector, err := forge.NewConnector(repo.UnvalidatedConfig, repo.UnvalidatedConfig.NormalConfig.DevRemote, print.Logger{})
 	if err != nil {
 		return data, false, err
 	}
@@ -263,9 +279,6 @@ func determineCompressBranchesData(repo execute.OpenRepoResult, dryRun configdom
 	if len(branchesToCompress) == 0 {
 		return data, exit, fmt.Errorf(messages.CompressNoCommits, branchNamesToCompress[0])
 	}
-	if len(branchesToCompress) == 1 && branchesToCompress[0].commitCount == 1 {
-		return data, exit, fmt.Errorf(messages.CompressAlreadyOneCommit, branchNamesToCompress[0])
-	}
 	return compressBranchesData{
 		branchesSnapshot:   branchesSnapshot,
 		branchesToCompress: branchesToCompress,
