@@ -13,9 +13,9 @@ import (
 	"github.com/git-town/git-town/v18/internal/config/configfile"
 	"github.com/git-town/git-town/v18/internal/config/gitconfig"
 	"github.com/git-town/git-town/v18/internal/execute"
+	"github.com/git-town/git-town/v18/internal/forge"
 	"github.com/git-town/git-town/v18/internal/git"
 	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	"github.com/git-town/git-town/v18/internal/hosting"
 	configInterpreter "github.com/git-town/git-town/v18/internal/vm/interpreter/config"
 	. "github.com/git-town/git-town/v18/pkg/prelude"
 	"github.com/spf13/cobra"
@@ -102,14 +102,14 @@ type userInput struct {
 	configStorage dialog.ConfigStorageOption
 }
 
-func determineHostingPlatform(config config.UnvalidatedConfig, userChoice Option[configdomain.HostingPlatform]) Option[configdomain.HostingPlatform] {
+func determineHostingPlatform(config config.UnvalidatedConfig, userChoice Option[configdomain.ForgeType]) Option[configdomain.ForgeType] {
 	if userChoice.IsSome() {
 		return userChoice
 	}
 	if devURL, hasDevURL := config.NormalConfig.DevURL().Get(); hasDevURL {
-		return hosting.Detect(devURL, userChoice)
+		return forge.Detect(devURL, userChoice)
 	}
-	return None[configdomain.HostingPlatform]()
+	return None[configdomain.ForgeType]()
 }
 
 func enterData(config config.UnvalidatedConfig, gitCommands git.Commands, backend gitdomain.RunnerQuerier, data *setupData) (aborted bool, err error) {
@@ -153,13 +153,13 @@ func enterData(config config.UnvalidatedConfig, gitCommands git.Commands, backen
 	if err != nil || aborted {
 		return aborted, err
 	}
-	data.userInput.config.NormalConfig.HostingPlatform, aborted, err = dialog.HostingPlatform(config.NormalConfig.HostingPlatform, data.dialogInputs.Next())
+	data.userInput.config.NormalConfig.ForgeType, aborted, err = dialog.ForgeType(config.NormalConfig.ForgeType, data.dialogInputs.Next())
 	if err != nil || aborted {
 		return aborted, err
 	}
-	if platform, has := determineHostingPlatform(config, data.userInput.config.NormalConfig.HostingPlatform).Get(); has {
+	if platform, has := determineHostingPlatform(config, data.userInput.config.NormalConfig.ForgeType).Get(); has {
 		switch platform {
-		case configdomain.HostingPlatformBitbucket, configdomain.HostingPlatformBitbucketDatacenter:
+		case configdomain.ForgeTypeBitbucket, configdomain.ForgeTypeBitbucketDatacenter:
 			data.userInput.config.NormalConfig.BitbucketUsername, aborted, err = dialog.BitbucketUsername(config.NormalConfig.BitbucketUsername, data.dialogInputs.Next())
 			if err != nil || aborted {
 				return aborted, err
@@ -168,17 +168,22 @@ func enterData(config config.UnvalidatedConfig, gitCommands git.Commands, backen
 			if err != nil || aborted {
 				return aborted, err
 			}
-		case configdomain.HostingPlatformGitea:
+		case configdomain.ForgeTypeCodeberg:
+			data.userInput.config.NormalConfig.CodebergToken, aborted, err = dialog.CodebergToken(config.NormalConfig.CodebergToken, data.dialogInputs.Next())
+			if err != nil || aborted {
+				return aborted, err
+			}
+		case configdomain.ForgeTypeGitea:
 			data.userInput.config.NormalConfig.GiteaToken, aborted, err = dialog.GiteaToken(config.NormalConfig.GiteaToken, data.dialogInputs.Next())
 			if err != nil || aborted {
 				return aborted, err
 			}
-		case configdomain.HostingPlatformGitHub:
+		case configdomain.ForgeTypeGitHub:
 			data.userInput.config.NormalConfig.GitHubToken, aborted, err = dialog.GitHubToken(config.NormalConfig.GitHubToken, data.dialogInputs.Next())
 			if err != nil || aborted {
 				return aborted, err
 			}
-		case configdomain.HostingPlatformGitLab:
+		case configdomain.ForgeTypeGitLab:
 			data.userInput.config.NormalConfig.GitLabToken, aborted, err = dialog.GitLabToken(config.NormalConfig.GitLabToken, data.dialogInputs.Next())
 			if err != nil || aborted {
 				return aborted, err
@@ -292,6 +297,10 @@ func saveAll(userInput userInput, oldConfig config.UnvalidatedConfig, gitCommand
 	if err != nil {
 		return err
 	}
+	err = saveCodebergToken(oldConfig.NormalConfig.CodebergToken, userInput.config.NormalConfig.CodebergToken, gitCommands, frontend)
+	if err != nil {
+		return err
+	}
 	err = saveGiteaToken(oldConfig.NormalConfig.GiteaToken, userInput.config.NormalConfig.GiteaToken, gitCommands, frontend)
 	if err != nil {
 		return err
@@ -316,7 +325,7 @@ func saveAll(userInput userInput, oldConfig config.UnvalidatedConfig, gitCommand
 func saveToGit(userInput userInput, oldConfig config.UnvalidatedConfig, gitCommands git.Commands, frontend gitdomain.Runner) error {
 	fc := execute.FailureCollector{}
 	fc.Check(saveNewBranchType(oldConfig.NormalConfig.NewBranchType, userInput.config.NormalConfig.NewBranchType, oldConfig))
-	fc.Check(saveHostingPlatform(oldConfig.NormalConfig.HostingPlatform, userInput.config.NormalConfig.HostingPlatform, gitCommands, frontend))
+	fc.Check(saveForgeType(oldConfig.NormalConfig.ForgeType, userInput.config.NormalConfig.ForgeType, gitCommands, frontend))
 	fc.Check(saveOriginHostname(oldConfig.NormalConfig.HostingOriginHostname, userInput.config.NormalConfig.HostingOriginHostname, gitCommands, frontend))
 	fc.Check(saveMainBranch(oldConfig.UnvalidatedConfig.MainBranch, userInput.config.UnvalidatedConfig.MainBranch.GetOrPanic(), oldConfig))
 	fc.Check(savePerennialBranches(oldConfig.NormalConfig.PerennialBranches, userInput.config.NormalConfig.PerennialBranches, oldConfig))
@@ -409,6 +418,31 @@ func saveFeatureRegex(oldValue, newValue Option[configdomain.FeatureRegex], conf
 	return nil
 }
 
+func saveForgeType(oldForgeType, newForgeType Option[configdomain.ForgeType], gitCommands git.Commands, frontend gitdomain.Runner) (err error) {
+	oldValue, oldHas := oldForgeType.Get()
+	newValue, newHas := newForgeType.Get()
+	if !oldHas && !newHas {
+		return nil
+	}
+	if oldValue == newValue {
+		return nil
+	}
+	if newHas {
+		return gitCommands.SetForgeType(frontend, newValue)
+	}
+	return gitCommands.DeleteConfigEntryForgeType(frontend)
+}
+
+func saveCodebergToken(oldToken, newToken Option[configdomain.CodebergToken], gitCommands git.Commands, frontend gitdomain.Runner) error {
+	if newToken == oldToken {
+		return nil
+	}
+	if value, has := newToken.Get(); has {
+		return gitCommands.SetCodebergToken(frontend, value)
+	}
+	return gitCommands.RemoveCodebergToken(frontend)
+}
+
 func saveGiteaToken(oldToken, newToken Option[configdomain.GiteaToken], gitCommands git.Commands, frontend gitdomain.Runner) error {
 	if newToken == oldToken {
 		return nil
@@ -439,21 +473,6 @@ func saveGitLabToken(oldToken, newToken Option[configdomain.GitLabToken], gitCom
 	return gitCommands.RemoveGitLabToken(frontend)
 }
 
-func saveHostingPlatform(oldHostingPlatform, newHostingPlatform Option[configdomain.HostingPlatform], gitCommands git.Commands, frontend gitdomain.Runner) (err error) {
-	oldValue, oldHas := oldHostingPlatform.Get()
-	newValue, newHas := newHostingPlatform.Get()
-	if !oldHas && !newHas {
-		return nil
-	}
-	if oldValue == newValue {
-		return nil
-	}
-	if newHas {
-		return gitCommands.SetHostingPlatform(frontend, newValue)
-	}
-	return gitCommands.DeleteHostingPlatform(frontend)
-}
-
 func saveMainBranch(oldValue Option[gitdomain.LocalBranchName], newValue gitdomain.LocalBranchName, config config.UnvalidatedConfig) error {
 	if Some(newValue) == oldValue {
 		return nil
@@ -468,7 +487,7 @@ func saveOriginHostname(oldValue, newValue Option[configdomain.HostingOriginHost
 	if value, has := newValue.Get(); has {
 		return gitCommands.SetOriginHostname(frontend, value)
 	}
-	return gitCommands.DeleteOriginHostname(frontend)
+	return gitCommands.DeleteConfigEntryOriginHostname(frontend)
 }
 
 func savePerennialBranches(oldValue, newValue gitdomain.LocalBranchNames, config config.UnvalidatedConfig) error {
