@@ -5,10 +5,10 @@ import (
 	"os"
 	"strconv"
 
-	"github.com/git-town/git-town/v17/internal/cli/dialog"
-	"github.com/git-town/git-town/v17/internal/cli/dialog/components"
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/cli/dialog"
+	"github.com/git-town/git-town/v18/internal/cli/dialog/components"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
 	"github.com/spf13/cobra"
 )
 
@@ -25,16 +25,15 @@ func enterParentCmd() *cobra.Command {
 			for i := range amount {
 				localBranches = append(localBranches, gitdomain.NewLocalBranchName(fmt.Sprintf("branch-%d", i)))
 			}
-			main := gitdomain.NewLocalBranchName("main")
 			lineage := configdomain.Lineage{}
 			dialogTestInputs := components.LoadTestInputs(os.Environ())
 			_, _, err = dialog.Parent(dialog.ParentArgs{
-				Branch:          gitdomain.NewLocalBranchName("branch-2"),
-				DefaultChoice:   main,
+				Branch:          "branch-2",
+				DefaultChoice:   "main",
 				DialogTestInput: dialogTestInputs.Next(),
 				Lineage:         lineage,
 				LocalBranches:   localBranches,
-				MainBranch:      main,
+				MainBranch:      "main",
 			})
 			return err
 		},
