@@ -3,9 +3,9 @@ package debug
 import (
 	"os"
 
-	"github.com/git-town/git-town/v17/internal/cli/dialog"
-	"github.com/git-town/git-town/v17/internal/cli/dialog/components"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/cli/dialog"
+	"github.com/git-town/git-town/v18/internal/cli/dialog/components"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
 	"github.com/spf13/cobra"
 )
 
@@ -13,10 +13,9 @@ func selectCommitAuthorCmd() *cobra.Command {
 	return &cobra.Command{
 		Use: "select-commit-author",
 		RunE: func(_ *cobra.Command, _ []string) error {
-			branch := gitdomain.NewLocalBranchName("feature-branch")
 			authors := []gitdomain.Author{"Jean-Luc Picard <captain@enterprise.com>", "William Riker <numberone@enterprise.com>"}
 			dialogTestInputs := components.LoadTestInputs(os.Environ())
-			_, _, err := dialog.SelectSquashCommitAuthor(branch, authors, dialogTestInputs.Next())
+			_, _, err := dialog.SelectSquashCommitAuthor("feature-branch", authors, dialogTestInputs.Next())
 			return err
 		},
 	}
