@@ -11,27 +11,28 @@ import (
 	"github.com/git-town/git-town/v18/internal/cmd/cmdhelpers"
 	"github.com/git-town/git-town/v18/internal/config/configdomain"
 	"github.com/git-town/git-town/v18/internal/execute"
+	"github.com/git-town/git-town/v18/internal/forge"
 	"github.com/git-town/git-town/v18/internal/git/gitdomain"
 	"github.com/git-town/git-town/v18/internal/gohacks/slice"
-	"github.com/git-town/git-town/v18/internal/hosting"
 	"github.com/git-town/git-town/v18/internal/messages"
 	"github.com/git-town/git-town/v18/internal/validate"
 	. "github.com/git-town/git-town/v18/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
-const diffParentDesc = "Show the changes committed to a feature branch"
-
-const diffParentHelp = `
+const (
+	diffParentDesc = "Show the changes committed to a branch"
+	diffParentHelp = `
 Works on either the current branch or the branch name provided.
 
 Exits with error code 1 if the given branch is a perennial branch or the main branch.`
+)
 
 func diffParentCommand() *cobra.Command {
 	addVerboseFlag, readVerboseFlag := flags.Verbose()
 	cmd := cobra.Command{
 		Use:     "diff-parent [<branch>]",
-		GroupID: "stack",
+		GroupID: cmdhelpers.GroupIDStack,
 		Args:    cobra.MaximumNArgs(1),
 		Short:   diffParentDesc,
 		Long:    cmdhelpers.Long(diffParentDesc, diffParentHelp),
@@ -115,7 +116,7 @@ func determineDiffParentData(args []string, repo execute.OpenRepoResult, verbose
 	}
 	localBranches := branchesSnapshot.Branches.LocalBranches().Names()
 	branchesAndTypes := repo.UnvalidatedConfig.UnvalidatedBranchesAndTypes(branchesSnapshot.Branches.LocalBranches().Names())
-	connector, err := hosting.NewConnector(repo.UnvalidatedConfig, repo.UnvalidatedConfig.NormalConfig.DevRemote, print.Logger{})
+	connector, err := forge.NewConnector(repo.UnvalidatedConfig, repo.UnvalidatedConfig.NormalConfig.DevRemote, print.Logger{})
 	if err != nil {
 		return data, false, err
 	}
