@@ -14,12 +14,11 @@ import (
 	"github.com/git-town/git-town/v18/internal/config"
 	"github.com/git-town/git-town/v18/internal/config/configdomain"
 	"github.com/git-town/git-town/v18/internal/execute"
+	"github.com/git-town/git-town/v18/internal/forge"
 	"github.com/git-town/git-town/v18/internal/git"
 	"github.com/git-town/git-town/v18/internal/git/gitdomain"
 	"github.com/git-town/git-town/v18/internal/gohacks"
 	"github.com/git-town/git-town/v18/internal/gohacks/stringslice"
-	"github.com/git-town/git-town/v18/internal/hosting"
-	"github.com/git-town/git-town/v18/internal/hosting/hostingdomain"
 	"github.com/git-town/git-town/v18/internal/messages"
 	"github.com/git-town/git-town/v18/internal/undo/undoconfig"
 	"github.com/git-town/git-town/v18/internal/validate"
@@ -31,25 +30,59 @@ import (
 	"github.com/spf13/cobra"
 )
 
-const hackDesc = "Create a new feature branch off the main branch"
+const (
+	hackDesc = "Create a new feature branch off the main branch"
+	hackHelp = `
+Consider this stack:
 
-const hackHelp = `
-Syncs the main branch, forks a new feature branch with the given name off the main branch, pushes the new feature branch to origin (if and only if "push-new-branches" is true), and brings over all uncommitted changes to the new feature branch.
+main
+ \
+  branch-1
+   \
+*   branch-2
 
-See "sync" for information regarding upstream remotes.`
+We are on the "branch-2" branch. After running "git hack branch-3", our
+workspace contains these branches:
+
+main
+ \
+  branch-1
+   \
+    branch-2
+ \
+* branch-3
+
+The new branch "feature-2"
+is a child of the main branch.
+
+If there are no uncommitted changes,
+it also syncs all affected branches.
+`
+)
 
 func hackCmd() *cobra.Command {
+	addCommitFlag, readCommitFlag := flags.Commit()
 	addDetachedFlag, readDetachedFlag := flags.Detached()
 	addDryRunFlag, readDryRunFlag := flags.DryRun()
+	addCommitMessageFlag, readCommitMessageFlag := flags.CommitMessage("the commit message")
+	addProposeFlag, readProposeFlag := flags.Propose()
 	addPrototypeFlag, readPrototypeFlag := flags.Prototype()
 	addVerboseFlag, readVerboseFlag := flags.Verbose()
 	cmd := cobra.Command{
 		Use:     "hack <branch>",
-		GroupID: "basic",
+		GroupID: cmdhelpers.GroupIDBasic,
 		Args:    cobra.ArbitraryArgs,
 		Short:   hackDesc,
 		Long:    cmdhelpers.Long(hackDesc, hackHelp),
 		RunE: func(cmd *cobra.Command, args []string) error {
+			commit, err := readCommitFlag(cmd)
+			if err != nil {
+				return err
+			}
+			commitMessage, err := readCommitMessageFlag(cmd)
+			if err != nil {
+				return err
+			}
 			detached, err := readDetachedFlag(cmd)
 			if err != nil {
 				return err
@@ -58,6 +91,10 @@ func hackCmd() *cobra.Command {
 			if err != nil {
 				return err
 			}
+			propose, err := readProposeFlag(cmd)
+			if err != nil {
+				return err
+			}
 			prototype, err := readPrototypeFlag(cmd)
 			if err != nil {
 				return err
@@ -66,17 +103,23 @@ func hackCmd() *cobra.Command {
 			if err != nil {
 				return err
 			}
-			return executeHack(args, detached, dryRun, prototype, verbose)
+			if commitMessage.IsSome() || propose.IsTrue() {
+				commit = true
+			}
+			return executeHack(args, commit, commitMessage, detached, dryRun, propose, prototype, verbose)
 		},
 	}
+	addCommitFlag(&cmd)
+	addCommitMessageFlag(&cmd)
 	addDetachedFlag(&cmd)
 	addDryRunFlag(&cmd)
+	addProposeFlag(&cmd)
 	addPrototypeFlag(&cmd)
 	addVerboseFlag(&cmd)
 	return &cmd
 }
 
-func executeHack(args []string, detached configdomain.Detached, dryRun configdomain.DryRun, prototype configdomain.Prototype, verbose configdomain.Verbose) error {
+func executeHack(args []string, commit configdomain.Commit, commitMessage Option[gitdomain.CommitMessage], detached configdomain.Detached, dryRun configdomain.DryRun, propose configdomain.Propose, prototype configdomain.Prototype, verbose configdomain.Verbose) error {
 	repo, err := execute.OpenRepo(execute.OpenRepoArgs{
 		DryRun:           dryRun,
 		PrintBranchNames: true,
@@ -88,7 +131,7 @@ func executeHack(args []string, detached configdomain.Detached, dryRun configdom
 	if err != nil {
 		return err
 	}
-	data, exit, err := determineHackData(args, repo, detached, dryRun, prototype, verbose)
+	data, exit, err := determineHackData(args, repo, commit, commitMessage, detached, dryRun, propose, prototype, verbose)
 	if err != nil || exit {
 		return err
 	}
@@ -151,7 +194,7 @@ func createFeatureBranch(args createFeatureBranchArgs) error {
 		Backend:                 args.backend,
 		CommandsCounter:         args.commandsCounter,
 		Config:                  args.appendData.config,
-		Connector:               None[hostingdomain.Connector](),
+		Connector:               args.appendData.connector,
 		DialogTestInputs:        args.appendData.dialogTestInputs,
 		FinalMessages:           args.finalMessages,
 		Frontend:                args.frontend,
@@ -182,7 +225,7 @@ type createFeatureBranchArgs struct {
 	verbose               configdomain.Verbose
 }
 
-func determineHackData(args []string, repo execute.OpenRepoResult, detached configdomain.Detached, dryRun configdomain.DryRun, prototype configdomain.Prototype, verbose configdomain.Verbose) (data hackData, exit bool, err error) {
+func determineHackData(args []string, repo execute.OpenRepoResult, commit configdomain.Commit, commitMessage Option[gitdomain.CommitMessage], detached configdomain.Detached, dryRun configdomain.DryRun, propose configdomain.Propose, prototype configdomain.Prototype, verbose configdomain.Verbose) (data hackData, exit bool, err error) {
 	preFetchBranchSnapshot, err := repo.Git.BranchesSnapshot(repo.Backend)
 	if err != nil {
 		return data, false, err
@@ -231,7 +274,7 @@ func determineHackData(args []string, repo execute.OpenRepoResult, detached conf
 			branchesToValidate = targetBranches
 		}
 	}
-	connector, err := hosting.NewConnector(repo.UnvalidatedConfig, repo.UnvalidatedConfig.NormalConfig.DevRemote, print.Logger{})
+	connector, err := forge.NewConnector(repo.UnvalidatedConfig, repo.UnvalidatedConfig.NormalConfig.DevRemote, print.Logger{})
 	if err != nil {
 		return data, false, err
 	}
@@ -254,7 +297,7 @@ func determineHackData(args []string, repo execute.OpenRepoResult, detached conf
 		return data, exit, err
 	}
 	if !shouldCreateBranch {
-		data = Right[appendFeatureData, convertToFeatureData](convertToFeatureData{
+		data = Right[appendFeatureData](convertToFeatureData{
 			config:         validatedConfig,
 			targetBranches: validatedConfig.BranchesAndTypes(branchesToValidate),
 		})
@@ -288,7 +331,10 @@ func determineHackData(args []string, repo execute.OpenRepoResult, detached conf
 		branchInfos:               branchesSnapshot.Branches,
 		branchesSnapshot:          branchesSnapshot,
 		branchesToSync:            branchesToSync,
+		commit:                    commit,
+		commitMessage:             commitMessage,
 		config:                    validatedConfig,
+		connector:                 connector,
 		dialogTestInputs:          dialogTestInputs,
 		dryRun:                    dryRun,
 		hasOpenChanges:            repoStatus.OpenChanges,
@@ -297,6 +343,7 @@ func determineHackData(args []string, repo execute.OpenRepoResult, detached conf
 		nonExistingBranches:       nonExistingBranches,
 		preFetchBranchInfos:       preFetchBranchSnapshot.Branches,
 		previousBranch:            previousBranch,
+		propose:                   propose,
 		prototype:                 prototype,
 		remotes:                   remotes,
 		stashSize:                 stashSize,
