@@ -17,17 +17,18 @@ import (
 	"github.com/spf13/cobra"
 )
 
-const offlineDesc = "Display or set offline mode"
-
-const offlineHelp = `
+const (
+	offlineDesc = "Display or set offline mode"
+	offlineHelp = `
 Git Town avoids network operations in offline mode.`
+)
 
 func offlineCmd() *cobra.Command {
 	addVerboseFlag, readVerboseFlag := flags.Verbose()
 	cmd := cobra.Command{
 		Use:     "offline [(yes | no)]",
 		Args:    cobra.MaximumNArgs(1),
-		GroupID: "setup",
+		GroupID: cmdhelpers.GroupIDSetup,
 		Short:   offlineDesc,
 		Long:    cmdhelpers.Long(offlineDesc, offlineHelp),
 		RunE: func(cmd *cobra.Command, args []string) error {
