@@ -15,22 +15,23 @@ import (
 	"github.com/spf13/cobra"
 )
 
-const parkDesc = "Suspend syncing of some feature branches"
-
-const parkHelp = `
+const (
+	parkDesc = "Suspend syncing of some feature branches"
+	parkHelp = `
 Parks the given local feature branches.
 If no branch is provided, parks the current branch.
 
 Git Town does not sync parked branches.
 The currently checked out branch gets synced even if parked.
 `
+)
 
 func parkCmd() *cobra.Command {
 	addVerboseFlag, readVerboseFlag := flags.Verbose()
 	cmd := cobra.Command{
 		Use:     "park [branches]",
 		Args:    cobra.ArbitraryArgs,
-		GroupID: "types",
+		GroupID: cmdhelpers.GroupIDTypes,
 		Short:   parkDesc,
 		Long:    cmdhelpers.Long(parkDesc, parkHelp),
 		RunE: func(cmd *cobra.Command, args []string) error {
