@@ -16,10 +16,10 @@ import (
 	"github.com/git-town/git-town/v18/internal/config"
 	"github.com/git-town/git-town/v18/internal/config/configdomain"
 	"github.com/git-town/git-town/v18/internal/execute"
+	"github.com/git-town/git-town/v18/internal/forge"
+	"github.com/git-town/git-town/v18/internal/forge/forgedomain"
 	"github.com/git-town/git-town/v18/internal/git/gitdomain"
 	"github.com/git-town/git-town/v18/internal/gohacks/stringslice"
-	"github.com/git-town/git-town/v18/internal/hosting"
-	"github.com/git-town/git-town/v18/internal/hosting/hostingdomain"
 	"github.com/git-town/git-town/v18/internal/messages"
 	"github.com/git-town/git-town/v18/internal/undo/undoconfig"
 	"github.com/git-town/git-town/v18/internal/validate"
@@ -33,16 +33,41 @@ import (
 	"github.com/spf13/cobra"
 )
 
-const prependDesc = "Create a new feature branch as the parent of the current branch"
+const (
+	prependDesc = "Create a new feature branch as the parent of the current branch"
+	prependHelp = `
+Syncs the parent branch,
+cuts a new feature branch with the given name off the parent branch,
+makes the new branch the parent of the current branch,
+pushes the new feature branch to the origin repository
+(if "push-new-branches" is true),
+and brings over all uncommitted changes to the new feature branch.
 
-const prependHelp = `
-Syncs the parent branch, cuts a new feature branch with the given name off the parent branch, makes the new branch the parent of the current branch, pushes the new feature branch to the origin repository (if "push-new-branches" is true), and brings over all uncommitted changes to the new feature branch.
+See "sync" for upstream remote options.
 
-See "sync" for upstream remote options.`
+Consider this stack:
+
+main
+ \
+* feature-2
+
+We are on the "feature-2" branch.
+After running "git town prepend feature-1",
+our repository has this stack:
+
+main
+ \
+* feature-1
+   \
+    feature-2
+`
+)
 
 func prependCommand() *cobra.Command {
 	addBeamFlag, readBeamFlag := flags.Beam()
 	addBodyFlag, readBodyFlag := flags.ProposalBody("")
+	addCommitFlag, readCommitFlag := flags.Commit()
+	addCommitMessageFlag, readCommitMessageFlag := flags.CommitMessage("the commit message")
 	addDetachedFlag, readDetachedFlag := flags.Detached()
 	addDryRunFlag, readDryRunFlag := flags.DryRun()
 	addProposeFlag, readProposeFlag := flags.Propose()
@@ -51,7 +76,7 @@ func prependCommand() *cobra.Command {
 	addVerboseFlag, readVerboseFlag := flags.Verbose()
 	cmd := cobra.Command{
 		Use:     "prepend <branch>",
-		GroupID: "stack",
+		GroupID: cmdhelpers.GroupIDStack,
 		Args:    cobra.ExactArgs(1),
 		Short:   prependDesc,
 		Long:    cmdhelpers.Long(prependDesc, prependHelp),
@@ -64,6 +89,14 @@ func prependCommand() *cobra.Command {
 			if err != nil {
 				return err
 			}
+			commit, err := readCommitFlag(cmd)
+			if err != nil {
+				return err
+			}
+			commitMessage, err := readCommitMessageFlag(cmd)
+			if err != nil {
+				return err
+			}
 			detached, err := readDetachedFlag(cmd)
 			if err != nil {
 				return err
@@ -88,11 +121,19 @@ func prependCommand() *cobra.Command {
 			if err != nil {
 				return err
 			}
-			return executePrepend(args, beam, bodyText, detached, dryRun, propose, prototype, title, verbose)
+			if commitMessage.IsSome() {
+				commit = true
+			}
+			if propose.IsTrue() && beam.IsFalse() {
+				commit = true
+			}
+			return executePrepend(args, beam, bodyText, commit, commitMessage, detached, dryRun, propose, prototype, title, verbose)
 		},
 	}
 	addBeamFlag(&cmd)
 	addBodyFlag(&cmd)
+	addCommitFlag(&cmd)
+	addCommitMessageFlag(&cmd)
 	addDetachedFlag(&cmd)
 	addDryRunFlag(&cmd)
 	addProposeFlag(&cmd)
@@ -102,7 +143,7 @@ func prependCommand() *cobra.Command {
 	return &cmd
 }
 
-func executePrepend(args []string, beam configdomain.Beam, proposalBody gitdomain.ProposalBody, detached configdomain.Detached, dryRun configdomain.DryRun, propose configdomain.Propose, prototype configdomain.Prototype, proposalTitle gitdomain.ProposalTitle, verbose configdomain.Verbose) error {
+func executePrepend(args []string, beam configdomain.Beam, proposalBody gitdomain.ProposalBody, commit configdomain.Commit, commitMessage Option[gitdomain.CommitMessage], detached configdomain.Detached, dryRun configdomain.DryRun, propose configdomain.Propose, prototype configdomain.Prototype, proposalTitle gitdomain.ProposalTitle, verbose configdomain.Verbose) error {
 	repo, err := execute.OpenRepo(execute.OpenRepoArgs{
 		DryRun:           dryRun,
 		PrintBranchNames: true,
@@ -114,7 +155,7 @@ func executePrepend(args []string, beam configdomain.Beam, proposalBody gitdomai
 	if err != nil {
 		return err
 	}
-	data, exit, err := determinePrependData(args, repo, beam, detached, dryRun, proposalBody, proposalTitle, propose, prototype, verbose)
+	data, exit, err := determinePrependData(args, repo, beam, commit, commitMessage, detached, dryRun, proposalBody, proposalTitle, propose, prototype, verbose)
 	if err != nil || exit {
 		return err
 	}
@@ -156,9 +197,11 @@ type prependData struct {
 	branchInfos         gitdomain.BranchInfos
 	branchesSnapshot    gitdomain.BranchesSnapshot
 	branchesToSync      configdomain.BranchesToSync
+	commit              configdomain.Commit
+	commitMessage       Option[gitdomain.CommitMessage]
 	commitsToBeam       gitdomain.Commits
 	config              config.ValidatedConfig
-	connector           Option[hostingdomain.Connector]
+	connector           Option[forgedomain.Connector]
 	dialogTestInputs    components.TestInputs
 	dryRun              configdomain.DryRun
 	existingParent      gitdomain.LocalBranchName
@@ -168,7 +211,7 @@ type prependData struct {
 	nonExistingBranches gitdomain.LocalBranchNames // branches that are listed in the lineage information, but don't exist in the repo, neither locally nor remotely
 	preFetchBranchInfos gitdomain.BranchInfos
 	previousBranch      Option[gitdomain.LocalBranchName]
-	proposal            Option[hostingdomain.Proposal]
+	proposal            Option[forgedomain.Proposal]
 	proposalBody        gitdomain.ProposalBody
 	proposalTitle       gitdomain.ProposalTitle
 	propose             configdomain.Propose
@@ -178,7 +221,7 @@ type prependData struct {
 	targetBranch        gitdomain.LocalBranchName
 }
 
-func determinePrependData(args []string, repo execute.OpenRepoResult, beam configdomain.Beam, detached configdomain.Detached, dryRun configdomain.DryRun, propasalBody gitdomain.ProposalBody, proposalTitle gitdomain.ProposalTitle, propose configdomain.Propose, prototype configdomain.Prototype, verbose configdomain.Verbose) (data prependData, exit bool, err error) {
+func determinePrependData(args []string, repo execute.OpenRepoResult, beam configdomain.Beam, commit configdomain.Commit, commitMessage Option[gitdomain.CommitMessage], detached configdomain.Detached, dryRun configdomain.DryRun, propasalBody gitdomain.ProposalBody, proposalTitle gitdomain.ProposalTitle, propose configdomain.Propose, prototype configdomain.Prototype, verbose configdomain.Verbose) (data prependData, exit bool, err error) {
 	prefetchBranchSnapshot, err := repo.Git.BranchesSnapshot(repo.Backend)
 	if err != nil {
 		return data, false, err
@@ -223,7 +266,7 @@ func determinePrependData(args []string, repo execute.OpenRepoResult, beam confi
 	if !hasInitialBranch {
 		return data, false, errors.New(messages.CurrentBranchCannotDetermine)
 	}
-	connector, err := hosting.NewConnector(repo.UnvalidatedConfig, repo.UnvalidatedConfig.NormalConfig.DevRemote, print.Logger{})
+	connector, err := forge.NewConnector(repo.UnvalidatedConfig, repo.UnvalidatedConfig.NormalConfig.DevRemote, print.Logger{})
 	if err != nil {
 		return data, false, err
 	}
@@ -256,7 +299,7 @@ func determinePrependData(args []string, repo execute.OpenRepoResult, beam confi
 		if err != nil {
 			return data, false, err
 		}
-		commitsToBeam, exit, err = dialog.CommitsToBeam(commitsInBranch, ancestor, dialogTestInputs.Next())
+		commitsToBeam, exit, err = dialog.CommitsToBeam(commitsInBranch, targetBranch, dialogTestInputs.Next())
 		if err != nil || exit {
 			return data, exit, err
 		}
@@ -272,7 +315,7 @@ func determinePrependData(args []string, repo execute.OpenRepoResult, beam confi
 	}
 	parentAndAncestors := validatedConfig.NormalConfig.Lineage.BranchAndAncestors(ancestor)
 	slices.Reverse(parentAndAncestors)
-	proposalOpt := None[hostingdomain.Proposal]()
+	proposalOpt := None[forgedomain.Proposal]()
 	if !repo.IsOffline {
 		proposalOpt = ship.FindProposal(connector, initialBranch, Some(ancestor))
 	}
@@ -280,6 +323,8 @@ func determinePrependData(args []string, repo execute.OpenRepoResult, beam confi
 		branchInfos:         branchesSnapshot.Branches,
 		branchesSnapshot:    branchesSnapshot,
 		branchesToSync:      branchesToSync,
+		commit:              commit,
+		commitMessage:       commitMessage,
 		commitsToBeam:       commitsToBeam,
 		config:              validatedConfig,
 		connector:           connector,
@@ -315,6 +360,7 @@ func prependProgram(data prependData, finalMessages stringslice.Collector) progr
 			InitialBranch:       data.initialBranch,
 			PrefetchBranchInfos: data.preFetchBranchInfos,
 			Program:             prog,
+			Prune:               false,
 			PushBranches:        true,
 			Remotes:             data.remotes,
 		})
@@ -333,7 +379,7 @@ func prependProgram(data prependData, finalMessages stringslice.Collector) progr
 		Branch: data.initialBranch,
 		Parent: data.targetBranch,
 	})
-	if data.prototype.IsTrue() {
+	if data.prototype {
 		prog.Value.Add(&opcodes.BranchTypeOverrideSet{Branch: data.targetBranch, BranchType: configdomain.BranchTypePrototypeBranch})
 	} else {
 		if newBranchType, hasNewBranchType := data.config.NormalConfig.NewBranchType.Get(); hasNewBranchType {
@@ -364,10 +410,19 @@ func prependProgram(data prependData, finalMessages stringslice.Collector) progr
 		})
 	}
 	moveCommitsToNewBranch(prog, data)
+	if data.commit {
+		prog.Value.Add(
+			&opcodes.Commit{
+				AuthorOverride:                 None[gitdomain.Author](),
+				FallbackToDefaultCommitMessage: false,
+				Message:                        data.commitMessage,
+			},
+		)
+	}
 	if data.propose {
 		prog.Value.Add(
-			&opcodes.PushCurrentBranchIfLocal{
-				CurrentBranch: data.targetBranch,
+			&opcodes.BranchTrackingCreate{
+				Branch: data.targetBranch,
 			},
 			&opcodes.ProposalCreate{
 				Branch:        data.targetBranch,
@@ -376,13 +431,19 @@ func prependProgram(data prependData, finalMessages stringslice.Collector) progr
 				ProposalTitle: data.proposalTitle,
 			})
 	}
-	previousBranchCandidates := []Option[gitdomain.LocalBranchName]{data.previousBranch}
-	cmdhelpers.Wrap(prog, cmdhelpers.WrapOptions{
-		DryRun:                   data.dryRun,
-		RunInGitRoot:             true,
-		StashOpenChanges:         data.hasOpenChanges,
-		PreviousBranchCandidates: previousBranchCandidates,
-	})
+	if data.commit {
+		prog.Value.Add(
+			&opcodes.Checkout{Branch: data.initialBranch},
+		)
+	} else {
+		previousBranchCandidates := []Option[gitdomain.LocalBranchName]{data.previousBranch}
+		cmdhelpers.Wrap(prog, cmdhelpers.WrapOptions{
+			DryRun:                   data.dryRun,
+			RunInGitRoot:             true,
+			StashOpenChanges:         data.hasOpenChanges,
+			PreviousBranchCandidates: previousBranchCandidates,
+		})
+	}
 	return optimizer.Optimize(prog.Immutable())
 }
 
