@@ -15,9 +15,9 @@ import (
 	"github.com/git-town/git-town/v18/internal/config"
 	"github.com/git-town/git-town/v18/internal/config/configdomain"
 	"github.com/git-town/git-town/v18/internal/execute"
+	"github.com/git-town/git-town/v18/internal/forge"
+	"github.com/git-town/git-town/v18/internal/forge/forgedomain"
 	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	"github.com/git-town/git-town/v18/internal/hosting"
-	"github.com/git-town/git-town/v18/internal/hosting/hostingdomain"
 	"github.com/git-town/git-town/v18/internal/messages"
 	"github.com/git-town/git-town/v18/internal/undo/undoconfig"
 	"github.com/git-town/git-town/v18/internal/validate"
@@ -31,16 +31,27 @@ import (
 	"github.com/spf13/cobra"
 )
 
-const proposeCmd = "propose"
+const (
+	proposeCmd  = "propose"
+	proposeDesc = "Create a proposal to merge a feature branch"
+	proposeHelp = `
+Syncs the current branch and opens a browser window
+to the new proposal page of your repository.
 
-const proposeDesc = "Create a proposal to merge a feature branch"
+The form is pre-populated for the current branch
+so that the proposal only shows the changes
+made against the immediate parent branch.
 
-const proposeHelp = `
-Syncs the current branch and opens a browser window to the new proposal page of your repository.
-
-The form is pre-populated for the current branch so that the proposal only shows the changes made against the immediate parent branch.
-
-Supported only for repositories hosted on GitHub, GitLab, Gitea and Bitbucket. When using self-hosted versions this command needs to be configured with "git config %s <driver>" where driver is "github", "gitlab", "gitea", or "bitbucket". When using SSH identities, this command needs to be configured with "git config %s <hostname>" where hostname matches what is in your ssh config file.`
+Supported only for repositories hosted on
+GitHub, GitLab, Gitea, Bitbucket, and Codeberg.
+When using self-hosted versions
+this command needs to be configured with "git config %s <driver>"
+where driver is "github", "gitlab", "gitea", or "bitbucket".
+When using SSH identities,
+this command needs to be configured with
+"git config %s <hostname>"
+where hostname matches what is in your ssh config file.`
+)
 
 func proposeCommand() *cobra.Command {
 	addBodyFlag, readBodyFlag := flags.ProposalBody("b")
@@ -51,10 +62,10 @@ func proposeCommand() *cobra.Command {
 	addVerboseFlag, readVerboseFlag := flags.Verbose()
 	cmd := cobra.Command{
 		Use:     proposeCmd,
-		GroupID: "basic",
+		GroupID: cmdhelpers.GroupIDBasic,
 		Args:    cobra.NoArgs,
 		Short:   proposeDesc,
-		Long:    cmdhelpers.Long(proposeDesc, fmt.Sprintf(proposeHelp, configdomain.KeyHostingPlatform, configdomain.KeyHostingOriginHostname)),
+		Long:    cmdhelpers.Long(proposeDesc, fmt.Sprintf(proposeHelp, configdomain.KeyForgeType, configdomain.KeyHostingOriginHostname)),
 		RunE: func(cmd *cobra.Command, _ []string) error {
 			detached, err := readDetachedFlag(cmd)
 			if err != nil {
@@ -153,7 +164,7 @@ type proposeData struct {
 	branchesSnapshot    gitdomain.BranchesSnapshot
 	branchesToSync      configdomain.BranchesToSync
 	config              config.ValidatedConfig
-	connector           Option[hostingdomain.Connector]
+	connector           Option[forgedomain.Connector]
 	dialogTestInputs    components.TestInputs
 	dryRun              configdomain.DryRun
 	existingProposalURL Option[string]
@@ -208,7 +219,7 @@ func determineProposeData(repo execute.OpenRepoResult, detached configdomain.Det
 	if !hasInitialBranch {
 		return data, false, errors.New(messages.CurrentBranchCannotDetermine)
 	}
-	connectorOpt, err := hosting.NewConnector(repo.UnvalidatedConfig, repo.UnvalidatedConfig.NormalConfig.DevRemote, print.Logger{})
+	connectorOpt, err := forge.NewConnector(repo.UnvalidatedConfig, repo.UnvalidatedConfig.NormalConfig.DevRemote, print.Logger{})
 	if err != nil {
 		return data, false, err
 	}
@@ -241,7 +252,7 @@ func determineProposeData(repo execute.OpenRepoResult, detached configdomain.Det
 	}
 	connector, hasConnector := connectorOpt.Get()
 	if !hasConnector {
-		return data, false, hostingdomain.UnsupportedServiceError()
+		return data, false, forgedomain.UnsupportedServiceError()
 	}
 	existingProposalURL := None[string]()
 	if findProposal, canFindProposal := connector.FindProposalFn().Get(); canFindProposal {
@@ -315,6 +326,7 @@ func proposeProgram(repo execute.OpenRepoResult, data proposeData) program.Progr
 		PrefetchBranchInfos: data.preFetchBranchInfos,
 		Remotes:             data.remotes,
 		Program:             prog,
+		Prune:               false,
 		PushBranches:        true,
 	})
 	if data.branchTypeToPropose == configdomain.BranchTypePrototypeBranch {
