@@ -9,19 +9,27 @@ import (
 	"github.com/git-town/git-town/v18/internal/cmd/cmdhelpers"
 	"github.com/git-town/git-town/v18/internal/config/configdomain"
 	"github.com/git-town/git-town/v18/internal/execute"
+	"github.com/git-town/git-town/v18/internal/forge"
+	"github.com/git-town/git-town/v18/internal/forge/forgedomain"
 	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	"github.com/git-town/git-town/v18/internal/hosting"
-	"github.com/git-town/git-town/v18/internal/hosting/hostingdomain"
 	. "github.com/git-town/git-town/v18/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
-const repoDesc = "Open the repository homepage in the browser"
+const (
+	repoDesc = "Open the repository homepage in the browser"
+	repoHelp = `
+Supported for repositories hosted on
+GitHub, GitLab, Gitea, Bitbucket, and Codeberg.
+Derives the Git provider from the "origin" remote.
+You can override this detection with
+"git config %s <DRIVER>"
+where DRIVER is "github", "gitlab", "gitea", or "bitbucket".
 
-const repoHelp = `
-Supported for repositories hosted on GitHub, GitLab, Gitea, and Bitbucket. Derives the Git provider from the "origin" remote. You can override this detection with "git config %s <DRIVER>" where DRIVER is "github", "gitlab", "gitea", or "bitbucket".
-
-When using SSH identities, run "git config %s <HOSTNAME>" where HOSTNAME matches what is in your ssh config file.`
+When using SSH identities, run
+"git config %s <HOSTNAME>"
+where HOSTNAME matches what is in your ssh config file.`
+)
 
 func repoCommand() *cobra.Command {
 	addVerboseFlag, readVerboseFlag := flags.Verbose()
@@ -29,7 +37,7 @@ func repoCommand() *cobra.Command {
 		Use:   "repo [remote]",
 		Args:  cobra.MaximumNArgs(1),
 		Short: repoDesc,
-		Long:  cmdhelpers.Long(repoDesc, fmt.Sprintf(repoHelp, configdomain.KeyHostingPlatform, configdomain.KeyHostingOriginHostname)),
+		Long:  cmdhelpers.Long(repoDesc, fmt.Sprintf(repoHelp, configdomain.KeyForgeType, configdomain.KeyHostingOriginHostname)),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			verbose, err := readVerboseFlag(cmd)
 			if err != nil {
@@ -74,13 +82,13 @@ func determineRepoData(args []string, repo execute.OpenRepoResult) (data repoDat
 	if !hasRemote {
 		return repoData{connector: nil}, nil
 	}
-	connectorOpt, err := hosting.NewConnector(repo.UnvalidatedConfig, remote, print.Logger{})
+	connectorOpt, err := forge.NewConnector(repo.UnvalidatedConfig, remote, print.Logger{})
 	if err != nil {
 		return data, err
 	}
 	connector, hasConnector := connectorOpt.Get()
 	if !hasConnector {
-		return data, hostingdomain.UnsupportedServiceError()
+		return data, forgedomain.UnsupportedServiceError()
 	}
 	return repoData{
 		connector: connector,
@@ -88,5 +96,5 @@ func determineRepoData(args []string, repo execute.OpenRepoResult) (data repoDat
 }
 
 type repoData struct {
-	connector hostingdomain.Connector
+	connector forgedomain.Connector
 }
