@@ -14,9 +14,9 @@ import (
 	"github.com/git-town/git-town/v18/internal/config"
 	"github.com/git-town/git-town/v18/internal/config/configdomain"
 	"github.com/git-town/git-town/v18/internal/execute"
+	"github.com/git-town/git-town/v18/internal/forge"
+	"github.com/git-town/git-town/v18/internal/forge/forgedomain"
 	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	"github.com/git-town/git-town/v18/internal/hosting"
-	"github.com/git-town/git-town/v18/internal/hosting/hostingdomain"
 	"github.com/git-town/git-town/v18/internal/messages"
 	"github.com/git-town/git-town/v18/internal/undo/undoconfig"
 	"github.com/git-town/git-town/v18/internal/validate"
@@ -29,15 +29,39 @@ import (
 	"github.com/spf13/cobra"
 )
 
-const setParentCmd = "set-parent"
+const (
+	setParentCmd  = "set-parent"
+	setParentDesc = "Set the parent branch for the current branch"
+	setParentHelp = `
+Consider this stack:
 
-const setParentDesc = "Set the parent branch for the current branch"
+main
+ \
+  feature-1
+   \
+*   feature-B
+ \
+  feature-A
+
+After running "git town set-parent"
+and selecting "feature-A" in the dialog,
+we end up with this stack:
+
+main
+ \
+  feature-1
+ \
+  feature-A
+   \
+*   feature-B
+`
+)
 
 func setParentCommand() *cobra.Command {
 	addVerboseFlag, readVerboseFlag := flags.Verbose()
 	cmd := cobra.Command{
 		Use:     setParentCmd,
-		GroupID: "stack",
+		GroupID: cmdhelpers.GroupIDStack,
 		Args:    cobra.NoArgs,
 		Short:   setParentDesc,
 		Long:    cmdhelpers.Long(setParentDesc),
@@ -124,13 +148,13 @@ func executeSetParent(verbose configdomain.Verbose) error {
 type setParentData struct {
 	branchesSnapshot gitdomain.BranchesSnapshot
 	config           config.ValidatedConfig
-	connector        Option[hostingdomain.Connector]
+	connector        Option[forgedomain.Connector]
 	defaultChoice    gitdomain.LocalBranchName
 	dialogTestInputs components.TestInputs
 	hasOpenChanges   bool
 	initialBranch    gitdomain.LocalBranchName
 	mainBranch       gitdomain.LocalBranchName
-	proposal         Option[hostingdomain.Proposal]
+	proposal         Option[forgedomain.Proposal]
 	stashSize        gitdomain.StashSize
 }
 
@@ -162,7 +186,7 @@ func determineSetParentData(repo execute.OpenRepoResult, verbose configdomain.Ve
 	}
 	localBranches := branchesSnapshot.Branches.LocalBranches().Names()
 	branchesAndTypes := repo.UnvalidatedConfig.UnvalidatedBranchesAndTypes(branchesSnapshot.Branches.LocalBranches().Names())
-	connectorOpt, err := hosting.NewConnector(repo.UnvalidatedConfig, repo.UnvalidatedConfig.NormalConfig.DevRemote, print.Logger{})
+	connectorOpt, err := forge.NewConnector(repo.UnvalidatedConfig, repo.UnvalidatedConfig.NormalConfig.DevRemote, print.Logger{})
 	if err != nil {
 		return data, false, err
 	}
@@ -196,7 +220,7 @@ func determineSetParentData(repo execute.OpenRepoResult, verbose configdomain.Ve
 	} else {
 		defaultChoice = mainBranch
 	}
-	proposalOpt := None[hostingdomain.Proposal]()
+	proposalOpt := None[forgedomain.Proposal]()
 	if !repo.IsOffline {
 		proposalOpt = ship.FindProposal(connectorOpt, initialBranch, parentOpt)
 	}
@@ -253,13 +277,21 @@ func setParentProgram(dialogOutcome dialog.ParentOutcome, selectedBranch gitdoma
 				)
 			}
 			parentOpt := data.config.NormalConfig.Lineage.Parent(data.initialBranch)
-			prog.Add(
-				&opcodes.RebaseOnto{
-					BranchToRebaseAgainst: data.initialBranch.BranchName(),
-					BranchToRebaseOnto:    selectedBranch,
-					Upstream:              parentOpt,
-				},
-			)
+			if parent, hasParent := parentOpt.Get(); hasParent {
+				prog.Add(
+					&opcodes.RebaseOntoKeepDeleted{
+						BranchToRebaseOnto: selectedBranch,
+						CommitsToRemove:    parent.BranchName(),
+						Upstream:           None[gitdomain.LocalBranchName](),
+					},
+				)
+			} else {
+				prog.Add(
+					&opcodes.RebaseBranch{
+						Branch: selectedBranch.BranchName(),
+					},
+				)
+			}
 			if hasRemoteBranch {
 				prog.Add(
 					&opcodes.PushCurrentBranchForce{ForceIfIncludes: true},
@@ -280,10 +312,10 @@ func setParentProgram(dialogOutcome dialog.ParentOutcome, selectedBranch gitdoma
 					)
 				}
 				prog.Add(
-					&opcodes.RebaseOnto{
-						BranchToRebaseAgainst: descendent.BranchName(),
-						BranchToRebaseOnto:    data.initialBranch,
-						Upstream:              parentOpt,
+					&opcodes.RebaseOntoRemoveDeleted{
+						BranchToRebaseOnto: data.initialBranch,
+						CommitsToRemove:    descendent.BranchName(),
+						Upstream:           parentOpt,
 					},
 				)
 				if hasDescendentBranchInfo && descendentBranchInfo.HasTrackingBranch() {
