@@ -4,18 +4,22 @@ import (
 	"regexp"
 	"testing"
 
-	"github.com/git-town/git-town/v17/internal/cli/dialog"
-	"github.com/git-town/git-town/v17/internal/cmd"
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/regexes"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
-	"github.com/git-town/git-town/v17/test/git"
+	"github.com/git-town/git-town/v18/internal/cli/dialog"
+	"github.com/git-town/git-town/v18/internal/cmd"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/regexes"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
 	"github.com/shoenig/test/must"
 )
 
 func TestSwitchBranch(t *testing.T) {
 	t.Parallel()
+	alpha := gitdomain.NewLocalBranchName("alpha")
+	beta := gitdomain.NewLocalBranchName("beta")
+	main := gitdomain.NewLocalBranchName("main")
+	prototype := gitdomain.NewLocalBranchName("prototype")
+	perennial := gitdomain.NewLocalBranchName("perennial")
 
 	t.Run("SwitchBranchCursorPos", func(t *testing.T) {
 		t.Parallel()
@@ -52,9 +56,6 @@ func TestSwitchBranch(t *testing.T) {
 			t.Parallel()
 			t.Run("all branches are in the current worktree", func(t *testing.T) {
 				t.Parallel()
-				alpha := gitdomain.NewLocalBranchName("alpha")
-				beta := gitdomain.NewLocalBranchName("beta")
-				main := gitdomain.NewLocalBranchName("main")
 				lineage := configdomain.NewLineageWith(configdomain.LineageData{
 					alpha: main,
 					beta:  main,
@@ -78,9 +79,6 @@ func TestSwitchBranch(t *testing.T) {
 			})
 			t.Run("one of the feature branches is in other worktree", func(t *testing.T) {
 				t.Parallel()
-				alpha := gitdomain.NewLocalBranchName("alpha")
-				beta := gitdomain.NewLocalBranchName("beta")
-				main := gitdomain.NewLocalBranchName("main")
 				lineage := configdomain.NewLineageWith(configdomain.LineageData{
 					alpha: main,
 					beta:  main,
@@ -106,10 +104,7 @@ func TestSwitchBranch(t *testing.T) {
 
 		t.Run("perennial branches", func(t *testing.T) {
 			t.Parallel()
-			alpha := gitdomain.NewLocalBranchName("alpha")
-			beta := gitdomain.NewLocalBranchName("beta")
 			perennial1 := gitdomain.NewLocalBranchName("perennial-1")
-			main := gitdomain.NewLocalBranchName("main")
 			lineage := configdomain.NewLineageWith(configdomain.LineageData{
 				alpha: main,
 				beta:  main,
@@ -140,7 +135,6 @@ func TestSwitchBranch(t *testing.T) {
 				t.Parallel()
 				local := gitdomain.NewLocalBranchName("local")
 				remote := gitdomain.NewRemoteBranchName("origin/remote")
-				main := gitdomain.NewLocalBranchName("main")
 				lineage := configdomain.NewLineage()
 				branchInfos := gitdomain.BranchInfos{
 					gitdomain.BranchInfo{LocalName: Some(main), SyncStatus: gitdomain.SyncStatusLocalOnly},
@@ -162,17 +156,16 @@ func TestSwitchBranch(t *testing.T) {
 				t.Parallel()
 				child := gitdomain.NewLocalBranchName("child")
 				grandchild := gitdomain.NewLocalBranchName("grandchild")
-				main := gitdomain.NewLocalBranchName("main")
 				lineage := configdomain.NewLineageWith(configdomain.LineageData{
 					child:      main,
 					grandchild: child,
 				})
 				branchInfos := gitdomain.BranchInfos{
-					gitdomain.BranchInfo{RemoteName: Some(child.AtRemote(git.RemoteOrigin)), SyncStatus: gitdomain.SyncStatusRemoteOnly},
+					gitdomain.BranchInfo{RemoteName: Some(child.AtRemote(gitdomain.RemoteOrigin)), SyncStatus: gitdomain.SyncStatusRemoteOnly},
 					gitdomain.BranchInfo{LocalName: Some(grandchild), SyncStatus: gitdomain.SyncStatusLocalOnly},
 					gitdomain.BranchInfo{LocalName: Some(main), SyncStatus: gitdomain.SyncStatusLocalOnly},
-					gitdomain.BranchInfo{LocalName: None[gitdomain.LocalBranchName](), RemoteName: Some(child.AtRemote(git.RemoteOrigin)), SyncStatus: gitdomain.SyncStatusLocalOnly},
-					gitdomain.BranchInfo{LocalName: Some(grandchild), RemoteName: Some(grandchild.AtRemote(git.RemoteOrigin)), SyncStatus: gitdomain.SyncStatusUpToDate},
+					gitdomain.BranchInfo{LocalName: None[gitdomain.LocalBranchName](), RemoteName: Some(child.AtRemote(gitdomain.RemoteOrigin)), SyncStatus: gitdomain.SyncStatusLocalOnly},
+					gitdomain.BranchInfo{LocalName: Some(grandchild), RemoteName: Some(grandchild.AtRemote(gitdomain.RemoteOrigin)), SyncStatus: gitdomain.SyncStatusUpToDate},
 				}
 				branchTypes := []configdomain.BranchType{}
 				branchesAndTypes := configdomain.BranchesAndTypes{}
@@ -189,7 +182,6 @@ func TestSwitchBranch(t *testing.T) {
 				t.Parallel()
 				local := gitdomain.NewLocalBranchName("local")
 				remote := gitdomain.NewRemoteBranchName("origin/remote")
-				main := gitdomain.NewLocalBranchName("main")
 				lineage := configdomain.NewLineageWith(configdomain.LineageData{
 					local: main,
 				})
@@ -218,9 +210,6 @@ func TestSwitchBranch(t *testing.T) {
 				t.Parallel()
 				observed1 := gitdomain.NewLocalBranchName("observed-1")
 				observed2 := gitdomain.NewLocalBranchName("observed-2")
-				prototype := gitdomain.NewLocalBranchName("prototype")
-				perennial := gitdomain.NewLocalBranchName("perennial")
-				main := gitdomain.NewLocalBranchName("main")
 				lineage := configdomain.NewLineage()
 				branchInfos := gitdomain.BranchInfos{
 					gitdomain.BranchInfo{LocalName: Some(observed1), SyncStatus: gitdomain.SyncStatusLocalOnly},
@@ -250,9 +239,6 @@ func TestSwitchBranch(t *testing.T) {
 				t.Parallel()
 				observed1 := gitdomain.NewLocalBranchName("observed-1")
 				observed2 := gitdomain.NewLocalBranchName("observed-2")
-				prototype := gitdomain.NewLocalBranchName("prototype")
-				perennial := gitdomain.NewLocalBranchName("perennial")
-				main := gitdomain.NewLocalBranchName("main")
 				lineage := configdomain.NewLineage()
 				branchInfos := gitdomain.BranchInfos{
 					gitdomain.BranchInfo{LocalName: Some(observed1), SyncStatus: gitdomain.SyncStatusLocalOnly},
@@ -290,9 +276,6 @@ func TestSwitchBranch(t *testing.T) {
 				t.Parallel()
 				observed1 := gitdomain.NewLocalBranchName("observed-1")
 				observed2 := gitdomain.NewLocalBranchName("observed-2")
-				prototype := gitdomain.NewLocalBranchName("prototype")
-				perennial := gitdomain.NewLocalBranchName("perennial")
-				main := gitdomain.NewLocalBranchName("main")
 				lineage := configdomain.NewLineage()
 				branchInfos := gitdomain.BranchInfos{
 					gitdomain.BranchInfo{LocalName: Some(main), SyncStatus: gitdomain.SyncStatusLocalOnly},
@@ -320,9 +303,6 @@ func TestSwitchBranch(t *testing.T) {
 				t.Parallel()
 				observed1 := gitdomain.NewLocalBranchName("observed-1")
 				observed2 := gitdomain.NewLocalBranchName("observed-2")
-				prototype := gitdomain.NewLocalBranchName("prototype")
-				perennial := gitdomain.NewLocalBranchName("perennial")
-				main := gitdomain.NewLocalBranchName("main")
 				lineage := configdomain.NewLineage()
 				branchInfos := gitdomain.BranchInfos{
 					gitdomain.BranchInfo{LocalName: Some(observed1), SyncStatus: gitdomain.SyncStatusLocalOnly},
@@ -347,9 +327,6 @@ func TestSwitchBranch(t *testing.T) {
 				t.Parallel()
 				observed1 := gitdomain.NewLocalBranchName("observed-1")
 				observed2 := gitdomain.NewLocalBranchName("observed-2")
-				prototype := gitdomain.NewLocalBranchName("prototype")
-				perennial := gitdomain.NewLocalBranchName("perennial")
-				main := gitdomain.NewLocalBranchName("main")
 				lineage := configdomain.NewLineage()
 				branchInfos := gitdomain.BranchInfos{
 					gitdomain.BranchInfo{LocalName: Some(main), SyncStatus: gitdomain.SyncStatusLocalOnly},
