@@ -1,10 +1,10 @@
 package configdomain
 
 import (
+	"maps"
 	"slices"
 
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"golang.org/x/exp/maps"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
 )
 
 type BranchesAndTypes map[gitdomain.LocalBranchName]BranchType
@@ -23,8 +23,18 @@ func (self *BranchesAndTypes) AddMany(branches gitdomain.LocalBranchNames, fullC
 	}
 }
 
+func (self *BranchesAndTypes) BranchesOfTypes(branchTypes ...BranchType) gitdomain.LocalBranchNames {
+	result := gitdomain.LocalBranchNames{}
+	for branchName, branchType := range *self {
+		if slices.Contains(branchTypes, branchType) {
+			result = append(result, branchName)
+		}
+	}
+	return result
+}
+
 func (self *BranchesAndTypes) Keys() gitdomain.LocalBranchNames {
-	result := maps.Keys(*self)
+	result := slices.Collect(maps.Keys(*self))
 	slices.Sort(result)
 	return result
 }
