@@ -56,6 +56,7 @@ const (
 	KeyAliasSync                           = Key("alias.sync")
 	KeyBitbucketAppPassword                = Key("git-town.bitbucket-app-password")
 	KeyBitbucketUsername                   = Key("git-town.bitbucket-username")
+	KeyCodebergToken                       = Key("git-town.codeberg-token")
 	KeyContributionBranches                = Key("git-town.contribution-branches")
 	KeyContributionRegex                   = Key("git-town.contribution-regex")
 	KeyDefaultBranchType                   = Key("git-town.default-branch-type")
@@ -65,6 +66,7 @@ const (
 	KeyDeprecatedCreatePrototypeBranches   = Key("git-town.create-prototype-branches")
 	KeyDeprecatedAliasKill                 = Key("alias.kill")
 	KeyDeprecatedAliasRenameBranch         = Key("alias.rename-branch")
+	KeyDeprecatedHostingPlatform           = Key("git-town.hosting-platform")
 	KeyDeprecatedMainBranchName            = Key("git-town.main-branch-name")
 	KeyDeprecatedNewBranchPushFlag         = Key("git-town.new-branch-push-flag")
 	KeyDeprecatedPerennialBranchNames      = Key("git-town.perennial-branch-names")
@@ -74,11 +76,11 @@ const (
 	KeyDeprecatedSyncStrategy              = Key("git-town.sync-strategy")
 	KeyDevRemote                           = Key("git-town.dev-remote")
 	KeyFeatureRegex                        = Key("git-town.feature-regex")
+	KeyForgeType                           = Key("git-town.forge-type")
 	KeyGiteaToken                          = Key("git-town.gitea-token")
 	KeyGithubToken                         = Key(pkg.KeyGithubToken)
 	KeyGitlabToken                         = Key("git-town.gitlab-token")
 	KeyHostingOriginHostname               = Key("git-town.hosting-origin-hostname")
-	KeyHostingPlatform                     = Key("git-town.hosting-platform")
 	KeyMainBranch                          = Key("git-town.main-branch")
 	KeyNewBranchType                       = Key("git-town.new-branch-type")
 	KeyObservedBranches                    = Key("git-town.observed-branches")
@@ -104,9 +106,9 @@ const (
 
 var keys = []Key{ //nolint:gochecknoglobals
 	KeyHostingOriginHostname,
-	KeyHostingPlatform,
 	KeyBitbucketAppPassword,
 	KeyBitbucketUsername,
+	KeyCodebergToken,
 	KeyContributionBranches,
 	KeyContributionRegex,
 	KeyDefaultBranchType,
@@ -116,6 +118,7 @@ var keys = []Key{ //nolint:gochecknoglobals
 	KeyDeprecatedCodeHostingOriginHostname,
 	KeyDeprecatedCodeHostingPlatform,
 	KeyDeprecatedCreatePrototypeBranches,
+	KeyDeprecatedHostingPlatform,
 	KeyDeprecatedMainBranchName,
 	KeyDeprecatedNewBranchPushFlag,
 	KeyDeprecatedPerennialBranchNames,
@@ -125,6 +128,7 @@ var keys = []Key{ //nolint:gochecknoglobals
 	KeyDeprecatedSyncStrategy,
 	KeyDevRemote,
 	KeyFeatureRegex,
+	KeyForgeType,
 	KeyGiteaToken,
 	KeyGithubToken,
 	KeyGitlabToken,
@@ -172,9 +176,10 @@ func ParseKey(name string) Option[Key] {
 
 // DeprecatedKeys defines the up-to-date counterparts to deprecated configuration settings.
 var DeprecatedKeys = map[Key]Key{ //nolint:gochecknoglobals
-	KeyDeprecatedCodeHostingDriver:         KeyHostingPlatform,
+	KeyDeprecatedCodeHostingDriver:         KeyForgeType,
 	KeyDeprecatedCodeHostingOriginHostname: KeyHostingOriginHostname,
-	KeyDeprecatedCodeHostingPlatform:       KeyHostingPlatform,
+	KeyDeprecatedCodeHostingPlatform:       KeyForgeType,
+	KeyDeprecatedHostingPlatform:           KeyForgeType,
 	KeyDeprecatedMainBranchName:            KeyMainBranch,
 	KeyDeprecatedNewBranchPushFlag:         KeyPushNewBranches,
 	KeyDeprecatedPerennialBranchNames:      KeyPerennialBranches,
