@@ -3,16 +3,16 @@ package configdomain
 import (
 	"cmp"
 	"fmt"
+	"maps"
 	"slices"
 	"strings"
 
-	"github.com/git-town/git-town/v17/internal/cli/colors"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/gohacks/mapstools"
-	"github.com/git-town/git-town/v17/internal/gohacks/slice"
-	"github.com/git-town/git-town/v17/internal/messages"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
-	"golang.org/x/exp/maps"
+	"github.com/git-town/git-town/v18/internal/cli/colors"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/gohacks/mapstools"
+	"github.com/git-town/git-town/v18/internal/gohacks/slice"
+	"github.com/git-town/git-town/v18/internal/messages"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
 )
 
 // Lineage encapsulates all data and functionality around parent branches.
@@ -33,23 +33,22 @@ func NewLineage() Lineage {
 func NewLineageFromSnapshot(snapshot SingleSnapshot, updateOutdated bool, removeLocalConfigValue removeLocalConfigValueFunc) (Lineage, error) {
 	result := NewLineage()
 	for key, value := range snapshot.LineageEntries() {
-		childName := key.ChildName()
-		if childName == "" {
+		child := key.ChildBranch()
+		if child == "" {
 			// empty lineage entries are invalid --> delete it
 			fmt.Println(colors.Cyan().Styled(messages.ConfigLineageEmptyChild))
-			_ = removeLocalConfigValue(key.Key())
+			_ = removeLocalConfigValue(key.Key)
 			continue
 		}
-		child := gitdomain.NewLocalBranchName(childName)
 		value = strings.TrimSpace(value)
 		if value == "" {
 			// empty lineage entries are invalid --> delete it
 			fmt.Println(colors.Cyan().Styled(messages.ConfigLineageEmptyChild))
-			_ = removeLocalConfigValue(key.Key())
+			_ = removeLocalConfigValue(key.Key)
 			continue
 		}
-		if updateOutdated && childName == value {
-			fmt.Println(colors.Cyan().Styled(fmt.Sprintf(messages.ConfigLineageParentIsChild, childName)))
+		if updateOutdated && child.String() == value {
+			fmt.Println(colors.Cyan().Styled(fmt.Sprintf(messages.ConfigLineageParentIsChild, child)))
 			_ = removeLocalConfigValue(NewParentKey(child))
 		}
 		parent := gitdomain.NewLocalBranchName(value)
@@ -95,16 +94,20 @@ func (self Lineage) BranchAndAncestors(branchName gitdomain.LocalBranchName) git
 
 // BranchLineageWithoutRoot provides all branches in the lineage of the given branch,
 // from oldest to youngest, including the given branch.
-func (self Lineage) BranchLineageWithoutRoot(branch gitdomain.LocalBranchName) gitdomain.LocalBranchNames {
+func (self Lineage) BranchLineageWithoutRoot(branch gitdomain.LocalBranchName, perennialBranches gitdomain.LocalBranchNames) gitdomain.LocalBranchNames {
 	if self.Parent(branch).IsNone() {
-		return self.Descendants(branch)
+		result := gitdomain.LocalBranchNames{}
+		if !perennialBranches.Contains(branch) {
+			result = append(result, branch)
+		}
+		return append(result, self.Descendants(branch)...)
 	}
 	return append(append(self.AncestorsWithoutRoot(branch), branch), self.Descendants(branch)...)
 }
 
 // BranchNames provides the names of all branches in this Lineage, sorted alphabetically.
 func (self Lineage) BranchNames() gitdomain.LocalBranchNames {
-	result := gitdomain.LocalBranchNames(maps.Keys(self.data))
+	result := gitdomain.LocalBranchNames(slices.Collect(maps.Keys(self.data)))
 	result.Sort()
 	return result
 }
@@ -121,7 +124,7 @@ func (self Lineage) BranchesAndAncestors(branchNames gitdomain.LocalBranchNames)
 
 // provides all branches for which the parent is known
 func (self Lineage) BranchesWithParents() gitdomain.LocalBranchNames {
-	var result gitdomain.LocalBranchNames = maps.Keys(self.data)
+	var result gitdomain.LocalBranchNames = slices.Collect(maps.Keys(self.data))
 	result.Sort()
 	return result
 }
