@@ -23,11 +23,22 @@ func (self SingleSnapshot) Aliases() Aliases {
 	return result
 }
 
+// provides all the configuration entries that describe branch type overrides
+func (self SingleSnapshot) BranchTypeOverrideEntries() map[BranchTypeOverrideKey]string {
+	result := map[BranchTypeOverrideKey]string{}
+	for key, value := range self {
+		if branchTypeKey, isBranchTypeKey := ParseBranchTypeOverrideKey(key).Get(); isBranchTypeKey {
+			result[branchTypeKey] = value
+		}
+	}
+	return result
+}
+
 // provides all the keys that describe lineage entries
 func (self SingleSnapshot) LineageEntries() map[LineageKey]string {
 	result := map[LineageKey]string{}
 	for key, value := range self {
-		if lineageKey, isLineageKey := NewLineageKey(key).Get(); isLineageKey {
+		if lineageKey, isLineageKey := ParseLineageKey(key).Get(); isLineageKey {
 			result[lineageKey] = value
 		}
 	}
