@@ -4,8 +4,8 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/git-town/git-town/v17/internal/messages"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
+	"github.com/git-town/git-town/v18/internal/messages"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
 )
 
 // SyncStrategy defines legal values for "sync-*-strategy" configuration settings.
@@ -16,6 +16,7 @@ func (self SyncStrategy) String() string { return string(self) }
 const (
 	SyncStrategyMerge    = SyncStrategy("merge")
 	SyncStrategyRebase   = SyncStrategy("rebase")
+	SyncStrategyFFOnly   = SyncStrategy("ff-only")
 	SyncStrategyCompress = SyncStrategy("compress")
 )
 
@@ -38,6 +39,7 @@ func SyncStrategies() []SyncStrategy {
 	return []SyncStrategy{
 		SyncStrategyMerge,
 		SyncStrategyRebase,
+		SyncStrategyFFOnly,
 		SyncStrategyCompress,
 	}
 }
