@@ -3,15 +3,15 @@ package configdomain_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
 	"github.com/shoenig/test/must"
 )
 
 func TestNewSyncStrategy(t *testing.T) {
 	t.Parallel()
 
-	t.Run("valid content", func(t *testing.T) {
+	t.Run("acceptable content", func(t *testing.T) {
 		t.Parallel()
 		tests := map[string]Option[configdomain.SyncStrategy]{
 			"":       None[configdomain.SyncStrategy](),
