@@ -4,17 +4,16 @@ import (
 	"fmt"
 	"strconv"
 
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/config/confighelpers"
-	"github.com/git-town/git-town/v17/internal/config/envconfig"
-	"github.com/git-town/git-town/v17/internal/config/gitconfig"
-	"github.com/git-town/git-town/v17/internal/git"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/git/giturl"
-	"github.com/git-town/git-town/v17/internal/gohacks/slice"
-	"github.com/git-town/git-town/v17/internal/gohacks/stringslice"
-	"github.com/git-town/git-town/v17/internal/messages"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/config/envconfig"
+	"github.com/git-town/git-town/v18/internal/config/gitconfig"
+	"github.com/git-town/git-town/v18/internal/git"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/git/giturl"
+	"github.com/git-town/git-town/v18/internal/gohacks"
+	"github.com/git-town/git-town/v18/internal/gohacks/stringslice"
+	"github.com/git-town/git-town/v18/internal/messages"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
 )
 
 type NormalConfig struct {
@@ -27,36 +26,6 @@ type NormalConfig struct {
 	LocalGitConfig  configdomain.PartialConfig         // content of the local Git configuration
 }
 
-// AddToContributionBranches registers the given branch names as contribution branches.
-// The branches must exist.
-func (self *NormalConfig) AddToContributionBranches(branches ...gitdomain.LocalBranchName) error {
-	return self.SetContributionBranches(append(self.ContributionBranches, branches...))
-}
-
-// AddToObservedBranches registers the given branch names as observed branches.
-// The branches must exist.
-func (self *NormalConfig) AddToObservedBranches(branches ...gitdomain.LocalBranchName) error {
-	return self.SetObservedBranches(append(self.ObservedBranches, branches...))
-}
-
-// AddToParkedBranches registers the given branch names as parked branches.
-// The branches must exist.
-func (self *NormalConfig) AddToParkedBranches(branches ...gitdomain.LocalBranchName) error {
-	return self.SetParkedBranches(append(self.ParkedBranches, branches...))
-}
-
-// AddToPerennialBranches registers the given branch names as perennial branches.
-// The branches must exist.
-func (self *NormalConfig) AddToPerennialBranches(branches ...gitdomain.LocalBranchName) error {
-	return self.SetPerennialBranches(append(self.PerennialBranches, branches...))
-}
-
-// AddToPrototypeBranches registers the given branch names as prototype branches.
-// The branches must exist.
-func (self *NormalConfig) AddToPrototypeBranches(branches ...gitdomain.LocalBranchName) error {
-	return self.SetPrototypeBranches(append(self.PrototypeBranches, branches...))
-}
-
 // removes the given branch from the lineage, and updates its children
 func (self *NormalConfig) CleanupBranchFromLineage(branch gitdomain.LocalBranchName) {
 	parent, hasParent := self.LocalGitConfig.Lineage.Parent(branch).Get()
@@ -85,11 +54,18 @@ func (self *NormalConfig) DevURL() Option[giturl.Parts] {
 // Tests can stub this through the GIT_TOWN_REMOTE environment variable.
 // Caches its result so can be called repeatedly.
 func (self *NormalConfig) RemoteURL(remote gitdomain.Remote) Option[giturl.Parts] {
-	text, hasText := self.RemoteURLString(remote).Get()
-	if !hasText {
+	urlStr, hasURLStr := self.RemoteURLString(remote).Get()
+	if !hasURLStr {
 		return None[giturl.Parts]()
 	}
-	return confighelpers.DetermineRemoteURL(text, self.HostingOriginHostname)
+	url, hasURL := giturl.Parse(urlStr).Get()
+	if !hasURL {
+		return None[giturl.Parts]()
+	}
+	if hostnameOverride, hasHostNameOverride := self.HostingOriginHostname.Get(); hasHostNameOverride {
+		url.Host = hostnameOverride.String()
+	}
+	return Some(url)
 }
 
 // RemoteURLString provides the URL for the given remote.
@@ -102,6 +78,13 @@ func (self *NormalConfig) RemoteURLString(remote gitdomain.Remote) Option[string
 	return self.GitConfigAccess.RemoteURL(remote)
 }
 
+func (self *NormalConfig) RemoveBranchTypeOverride(branch gitdomain.LocalBranchName) error {
+	delete(self.BranchTypeOverrides, branch)
+	key := configdomain.NewBranchTypeOverrideKeyForBranch(branch)
+	_ = self.GitConfigAccess.RemoveLocalConfigValue(key.Key)
+	return nil
+}
+
 func (self *NormalConfig) RemoveCreatePrototypeBranches() {
 	_ = self.GitConfigAccess.RemoveLocalConfigValue(configdomain.KeyDeprecatedCreatePrototypeBranches)
 }
@@ -114,36 +97,6 @@ func (self *NormalConfig) RemoveFeatureRegex() {
 	_ = self.GitConfigAccess.RemoveLocalConfigValue(configdomain.KeyFeatureRegex)
 }
 
-// RemoveFromContributionBranches removes the given branch as a perennial branch.
-func (self *NormalConfig) RemoveFromContributionBranches(branch gitdomain.LocalBranchName) error {
-	self.ContributionBranches = slice.Remove(self.ContributionBranches, branch)
-	return self.SetContributionBranches(self.ContributionBranches)
-}
-
-// RemoveFromObservedBranches removes the given branch as a perennial branch.
-func (self *NormalConfig) RemoveFromObservedBranches(branch gitdomain.LocalBranchName) error {
-	self.ObservedBranches = slice.Remove(self.ObservedBranches, branch)
-	return self.SetObservedBranches(self.ObservedBranches)
-}
-
-// RemoveFromParkedBranches removes the given branch as a perennial branch.
-func (self *NormalConfig) RemoveFromParkedBranches(branch gitdomain.LocalBranchName) error {
-	self.ParkedBranches = slice.Remove(self.ParkedBranches, branch)
-	return self.SetParkedBranches(self.ParkedBranches)
-}
-
-// RemoveFromPerennialBranches removes the given branch as a perennial branch.
-func (self *NormalConfig) RemoveFromPerennialBranches(branch gitdomain.LocalBranchName) error {
-	self.PerennialBranches = slice.Remove(self.PerennialBranches, branch)
-	return self.SetPerennialBranches(self.PerennialBranches)
-}
-
-// RemoveFromPerennialBranches removes the given branch as a perennial branch.
-func (self *NormalConfig) RemoveFromPrototypeBranches(branch gitdomain.LocalBranchName) error {
-	self.PrototypeBranches = slice.Remove(self.PrototypeBranches, branch)
-	return self.SetPrototypeBranches(self.PrototypeBranches)
-}
-
 func (self *NormalConfig) RemoveNewBranchType() {
 	_ = self.GitConfigAccess.RemoveLocalConfigValue(configdomain.KeyNewBranchType)
 }
@@ -208,6 +161,17 @@ func (self *NormalConfig) RemoveSyncUpstream() {
 	_ = self.GitConfigAccess.RemoveLocalConfigValue(configdomain.KeySyncUpstream)
 }
 
+// SetBranchTypeOverride registers the given branch names as contribution branches.
+// The branches must exist.
+func (self *NormalConfig) SetBranchTypeOverride(branchType configdomain.BranchType, branches ...gitdomain.LocalBranchName) error {
+	result := gohacks.ErrorCollector{}
+	for _, branch := range branches {
+		self.BranchTypeOverrides[branch] = branchType
+		result.Check(self.GitConfigAccess.SetConfigValue(configdomain.ConfigScopeLocal, configdomain.NewBranchTypeOverrideKeyForBranch(branch).Key, branchType.String()))
+	}
+	return result.Err
+}
+
 // SetObservedBranches marks the given branches as observed branches.
 func (self *NormalConfig) SetContributionBranches(branches gitdomain.LocalBranchNames) error {
 	self.ContributionBranches = branches
@@ -234,7 +198,7 @@ func (self *NormalConfig) SetFeatureRegexLocally(value configdomain.FeatureRegex
 
 // SetContributionBranches marks the given branches as contribution branches.
 func (self *NormalConfig) SetNewBranchType(value configdomain.BranchType) error {
-	self.NewBranchType = value
+	self.NewBranchType = Some(value)
 	return self.GitConfigAccess.SetConfigValue(configdomain.ConfigScopeLocal, configdomain.KeyNewBranchType, value.String())
 }
 
