@@ -1,9 +1,9 @@
 package config
 
 import (
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/gohacks/stringslice"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/gohacks/stringslice"
 )
 
 // Config provides type-safe access to Git Town configuration settings
@@ -32,6 +32,16 @@ func (self *ValidatedConfig) BranchesAndTypes(branches gitdomain.LocalBranchName
 	return result
 }
 
+func (self *ValidatedConfig) BranchesOfType(branches gitdomain.LocalBranchNames, branchType configdomain.BranchType) gitdomain.LocalBranchNames {
+	result := gitdomain.LocalBranchNames{}
+	for _, branch := range branches {
+		if self.BranchType(branch) == branchType {
+			result = append(result, branch)
+		}
+	}
+	return result
+}
+
 func (self *ValidatedConfig) CleanupLineage(branchInfos gitdomain.BranchInfos, nonExistingBranches gitdomain.LocalBranchNames, finalMessages stringslice.Collector) {
 	self.RemoveDeletedBranchesFromLineage(branchInfos, nonExistingBranches)
 	self.NormalConfig.RemovePerennialAncestors(finalMessages)
@@ -40,7 +50,8 @@ func (self *ValidatedConfig) CleanupLineage(branchInfos gitdomain.BranchInfos, n
 // IsMainOrPerennialBranch indicates whether the branch with the given name
 // is the main branch or a perennial branch of the repository.
 func (self *ValidatedConfig) IsMainOrPerennialBranch(branch gitdomain.LocalBranchName) bool {
-	return self.ValidatedConfigData.IsMainBranch(branch) || self.NormalConfig.IsPerennialBranch(branch)
+	branchType := self.BranchType(branch)
+	return branchType == configdomain.BranchTypeMainBranch || branchType == configdomain.BranchTypePerennialBranch
 }
 
 func (self *ValidatedConfig) MainAndPerennials() gitdomain.LocalBranchNames {
