@@ -41,6 +41,47 @@ func TestBackendCommands(t *testing.T) {
 		must.Eq(t, []gitdomain.Author{"user <email@example.com>"}, authors)
 	})
 
+	t.Run("BranchContainsMerges", func(t *testing.T) {
+		t.Parallel()
+		t.Run("branch has a merge commit", func(t *testing.T) {
+			t.Parallel()
+			runtime := testruntime.Create(t)
+			branch1 := gitdomain.NewLocalBranchName("branch-1")
+			branch2 := gitdomain.NewLocalBranchName("branch-2")
+			err := runtime.CreateAndCheckoutBranch(runtime, branch1)
+			must.NoError(t, err)
+			runtime.CreateBranch(branch2, branch1.BranchName())
+			runtime.CreateCommit(testgit.Commit{
+				Branch:      branch1,
+				FileContent: "content",
+				FileName:    "file1",
+				Message:     "commit 1",
+			})
+			runtime.CheckoutBranch(branch2)
+			err = runtime.MergeNoFastForward(runtime, configdomain.UseDefaultMessage(), branch1)
+			must.NoError(t, err)
+			have, err := runtime.BranchContainsMerges(runtime, branch2, branch1)
+			must.NoError(t, err)
+			must.True(t, have)
+		})
+		t.Run("branch has no merge commits", func(t *testing.T) {
+			t.Parallel()
+			runtime := testruntime.Create(t)
+			branch1 := gitdomain.NewLocalBranchName("branch-1")
+			err := runtime.CreateAndCheckoutBranch(runtime, branch1)
+			must.NoError(t, err)
+			runtime.CreateCommit(testgit.Commit{
+				Branch:      branch1,
+				FileContent: "content",
+				FileName:    "file1",
+				Message:     "commit 1",
+			})
+			have, err := runtime.BranchContainsMerges(runtime, branch1, initial)
+			must.NoError(t, err)
+			must.False(t, have)
+		})
+	})
+
 	t.Run("BranchHasUnmergedChanges", func(t *testing.T) {
 		t.Parallel()
 		t.Run("branch without commits", func(t *testing.T) {
@@ -84,6 +125,184 @@ func TestBackendCommands(t *testing.T) {
 		})
 	})
 
+	t.Run("BranchInSyncWithParent", func(t *testing.T) {
+		t.Parallel()
+		t.Run("child has the same commits as parent", func(t *testing.T) {
+			t.Parallel()
+			origin := testruntime.Create(t)
+			local := testruntime.Clone(origin.TestRunner, t.TempDir())
+			err := local.CreateAndCheckoutBranch(local.TestRunner, "parent")
+			must.NoError(t, err)
+			local.CreateCommit(testgit.Commit{
+				Branch:      "parent",
+				FileContent: "content",
+				FileName:    "parent_file",
+				Message:     "add parent file",
+			})
+			err = local.CreateAndCheckoutBranch(local.TestRunner, "child")
+			must.NoError(t, err)
+			inSync, err := local.BranchInSyncWithParent(local.TestRunner, "child", "parent")
+			must.NoError(t, err)
+			must.True(t, inSync)
+		})
+		t.Run("parent has extra commit", func(t *testing.T) {
+			t.Parallel()
+			origin := testruntime.Create(t)
+			local := testruntime.Clone(origin.TestRunner, t.TempDir())
+			err := local.CreateAndCheckoutBranch(local.TestRunner, "parent")
+			must.NoError(t, err)
+			local.CreateCommit(testgit.Commit{
+				Branch:      "parent",
+				FileContent: "content",
+				FileName:    "file",
+				Message:     "commit on both parent and child",
+			})
+			err = local.CreateAndCheckoutBranch(local.TestRunner, "child")
+			must.NoError(t, err)
+			local.CreateCommit(testgit.Commit{
+				Branch:      "parent",
+				FileContent: "content 2",
+				FileName:    "file",
+				Message:     "commit only on parent",
+			})
+			inSync, err := local.BranchInSyncWithParent(local.TestRunner, "child", "parent")
+			must.NoError(t, err)
+			must.False(t, inSync)
+		})
+		t.Run("child has extra commit", func(t *testing.T) {
+			t.Parallel()
+			origin := testruntime.Create(t)
+			local := testruntime.Clone(origin.TestRunner, t.TempDir())
+			err := local.CreateAndCheckoutBranch(local.TestRunner, "parent")
+			must.NoError(t, err)
+			local.CreateCommit(testgit.Commit{
+				Branch:      "parent",
+				FileContent: "content",
+				FileName:    "file",
+				Message:     "commit on both parent and child",
+			})
+			err = local.CreateAndCheckoutBranch(local.TestRunner, "child")
+			must.NoError(t, err)
+			local.CreateCommit(testgit.Commit{
+				Branch:      "child",
+				FileContent: "content 2",
+				FileName:    "file",
+				Message:     "commit only on child",
+			})
+			inSync, err := local.BranchInSyncWithParent(local.TestRunner, "child", "parent")
+			must.NoError(t, err)
+			must.True(t, inSync)
+		})
+		t.Run("empty parent", func(t *testing.T) {
+			t.Parallel()
+			origin := testruntime.Create(t)
+			local := testruntime.Clone(origin.TestRunner, t.TempDir())
+			err := local.CreateAndCheckoutBranch(local.TestRunner, "parent")
+			must.NoError(t, err)
+			err = local.CreateAndCheckoutBranch(local.TestRunner, "child")
+			must.NoError(t, err)
+			local.CreateCommit(testgit.Commit{
+				Branch:      "child",
+				FileContent: "content 2",
+				FileName:    "file",
+				Message:     "commit only on child",
+			})
+			inSync, err := local.BranchInSyncWithParent(local.TestRunner, "child", "parent")
+			must.NoError(t, err)
+			must.True(t, inSync)
+		})
+		t.Run("both empty", func(t *testing.T) {
+			t.Parallel()
+			origin := testruntime.Create(t)
+			local := testruntime.Clone(origin.TestRunner, t.TempDir())
+			err := local.CreateAndCheckoutBranch(local.TestRunner, "parent")
+			must.NoError(t, err)
+			err = local.CreateAndCheckoutBranch(local.TestRunner, "child")
+			must.NoError(t, err)
+			inSync, err := local.BranchInSyncWithParent(local.TestRunner, "child", "parent")
+			must.NoError(t, err)
+			must.True(t, inSync)
+		})
+	})
+
+	t.Run("BranchInSyncWithTracking", func(t *testing.T) {
+		t.Parallel()
+		t.Run("branch has no commits", func(t *testing.T) {
+			t.Parallel()
+			origin := testruntime.Create(t)
+			local := testruntime.Clone(origin.TestRunner, t.TempDir())
+			err := local.CreateAndCheckoutBranch(local.TestRunner, "branch")
+			must.NoError(t, err)
+			err = local.CreateTrackingBranch(local.TestRunner, "branch", gitdomain.RemoteOrigin, false)
+			must.NoError(t, err)
+			inSync, err := local.BranchInSyncWithTracking(local.TestRunner, "branch", gitdomain.RemoteOrigin)
+			must.NoError(t, err)
+			must.True(t, inSync)
+		})
+		t.Run("branch has local commits", func(t *testing.T) {
+			t.Parallel()
+			origin := testruntime.Create(t)
+			local := testruntime.Clone(origin.TestRunner, t.TempDir())
+			err := local.CreateAndCheckoutBranch(local.TestRunner, "branch")
+			must.NoError(t, err)
+			err = local.CreateTrackingBranch(local.TestRunner, "branch", gitdomain.RemoteOrigin, false)
+			must.NoError(t, err)
+			local.CreateCommit(testgit.Commit{
+				Branch:      "branch",
+				FileContent: "content",
+				FileName:    "local_file",
+				Message:     "add local file",
+			})
+			inSync, err := local.BranchInSyncWithTracking(local.TestRunner, "branch", gitdomain.RemoteOrigin)
+			must.NoError(t, err)
+			must.False(t, inSync)
+		})
+		t.Run("branch has remote commits", func(t *testing.T) {
+			t.Parallel()
+			origin := testruntime.Create(t)
+			local := testruntime.Clone(origin.TestRunner, t.TempDir())
+			err := local.CreateAndCheckoutBranch(local.TestRunner, "branch")
+			must.NoError(t, err)
+			err = local.CreateTrackingBranch(local.TestRunner, "branch", gitdomain.RemoteOrigin, false)
+			must.NoError(t, err)
+			origin.CreateCommit(testgit.Commit{
+				Branch:      "branch",
+				FileContent: "content",
+				FileName:    "remote_file",
+				Message:     "add remote file",
+			})
+			local.Fetch()
+			inSync, err := local.BranchInSyncWithTracking(local.TestRunner, "branch", gitdomain.RemoteOrigin)
+			must.NoError(t, err)
+			must.False(t, inSync)
+		})
+		t.Run("branch has different local and remote commits", func(t *testing.T) {
+			t.Parallel()
+			origin := testruntime.Create(t)
+			local := testruntime.Clone(origin.TestRunner, t.TempDir())
+			err := local.CreateAndCheckoutBranch(local.TestRunner, "branch")
+			must.NoError(t, err)
+			err = local.CreateTrackingBranch(local.TestRunner, "branch", gitdomain.RemoteOrigin, false)
+			must.NoError(t, err)
+			local.CreateCommit(testgit.Commit{
+				Branch:      "branch",
+				FileContent: "content",
+				FileName:    "local_file",
+				Message:     "add local file",
+			})
+			origin.CreateCommit(testgit.Commit{
+				Branch:      "branch",
+				FileContent: "content",
+				FileName:    "remote_file",
+				Message:     "add remote file",
+			})
+			local.Fetch()
+			inSync, err := local.BranchInSyncWithTracking(local.TestRunner, "branch", gitdomain.RemoteOrigin)
+			must.NoError(t, err)
+			must.False(t, inSync)
+		})
+	})
+
 	t.Run("CheckoutBranch", func(t *testing.T) {
 		t.Parallel()
 		runtime := testruntime.Create(t)
@@ -862,6 +1081,28 @@ func TestBackendCommands(t *testing.T) {
 			must.Eq(t, want, have)
 		})
 
+		t.Run("symbolic reference", func(t *testing.T) {
+			t.Parallel()
+			give := `
+  main                                   4dc97db26 [origin/main] Commit 1
+  remotes/origin/HEAD                    -> origin/main
+  remotes/origin/main                    4dc97db26 Commit 1
+  remotes/origin/master                  -> origin/main
+`[1:]
+			want := gitdomain.BranchInfos{
+				gitdomain.BranchInfo{
+					LocalName:  Some(gitdomain.NewLocalBranchName("main")),
+					LocalSHA:   Some(gitdomain.NewSHA("4dc97db26")),
+					SyncStatus: gitdomain.SyncStatusUpToDate,
+					RemoteName: Some(gitdomain.NewRemoteBranchName("origin/main")),
+					RemoteSHA:  Some(gitdomain.NewSHA("4dc97db26")),
+				},
+			}
+			have, currentBranch := git.ParseVerboseBranchesOutput(give)
+			must.Eq(t, want, have)
+			must.Eq(t, None[gitdomain.LocalBranchName](), currentBranch)
+		})
+
 		t.Run("complex example", func(t *testing.T) {
 			give := `
   branch-1                     01a7eded [origin/branch-1: ahead 1] Commit message 1a
@@ -1114,84 +1355,6 @@ func TestBackendCommands(t *testing.T) {
 		})
 	})
 
-	t.Run("ShouldPushBranch", func(t *testing.T) {
-		t.Parallel()
-		t.Run("branch has no commits", func(t *testing.T) {
-			t.Parallel()
-			origin := testruntime.Create(t)
-			local := testruntime.Clone(origin.TestRunner, t.TempDir())
-			err := local.CreateAndCheckoutBranch(local.TestRunner, "branch")
-			must.NoError(t, err)
-			err = local.CreateTrackingBranch(local.TestRunner, "branch", gitdomain.RemoteOrigin, false)
-			must.NoError(t, err)
-			shouldPush, err := local.ShouldPushBranch(local.TestRunner, "branch", gitdomain.RemoteOrigin)
-			must.NoError(t, err)
-			must.False(t, shouldPush)
-		})
-		t.Run("branch has local commits", func(t *testing.T) {
-			t.Parallel()
-			origin := testruntime.Create(t)
-			local := testruntime.Clone(origin.TestRunner, t.TempDir())
-			err := local.CreateAndCheckoutBranch(local.TestRunner, "branch")
-			must.NoError(t, err)
-			err = local.CreateTrackingBranch(local.TestRunner, "branch", gitdomain.RemoteOrigin, false)
-			must.NoError(t, err)
-			local.CreateCommit(testgit.Commit{
-				Branch:      "branch",
-				FileContent: "content",
-				FileName:    "local_file",
-				Message:     "add local file",
-			})
-			shouldPush, err := local.ShouldPushBranch(local.TestRunner, "branch", gitdomain.RemoteOrigin)
-			must.NoError(t, err)
-			must.True(t, shouldPush)
-		})
-		t.Run("branch has remote commits", func(t *testing.T) {
-			t.Parallel()
-			origin := testruntime.Create(t)
-			local := testruntime.Clone(origin.TestRunner, t.TempDir())
-			err := local.CreateAndCheckoutBranch(local.TestRunner, "branch")
-			must.NoError(t, err)
-			err = local.CreateTrackingBranch(local.TestRunner, "branch", gitdomain.RemoteOrigin, false)
-			must.NoError(t, err)
-			origin.CreateCommit(testgit.Commit{
-				Branch:      "branch",
-				FileContent: "content",
-				FileName:    "remote_file",
-				Message:     "add remote file",
-			})
-			local.Fetch()
-			shouldPush, err := local.ShouldPushBranch(local.TestRunner, "branch", gitdomain.RemoteOrigin)
-			must.NoError(t, err)
-			must.True(t, shouldPush)
-		})
-		t.Run("branch has different local and remote commits", func(t *testing.T) {
-			t.Parallel()
-			origin := testruntime.Create(t)
-			local := testruntime.Clone(origin.TestRunner, t.TempDir())
-			err := local.CreateAndCheckoutBranch(local.TestRunner, "branch")
-			must.NoError(t, err)
-			err = local.CreateTrackingBranch(local.TestRunner, "branch", gitdomain.RemoteOrigin, false)
-			must.NoError(t, err)
-			local.CreateCommit(testgit.Commit{
-				Branch:      "branch",
-				FileContent: "content",
-				FileName:    "local_file",
-				Message:     "add local file",
-			})
-			origin.CreateCommit(testgit.Commit{
-				Branch:      "branch",
-				FileContent: "content",
-				FileName:    "remote_file",
-				Message:     "add remote file",
-			})
-			local.Fetch()
-			shouldPush, err := local.ShouldPushBranch(local.TestRunner, "branch", gitdomain.RemoteOrigin)
-			must.NoError(t, err)
-			must.True(t, shouldPush)
-		})
-	})
-
 	t.Run("StashEntries", func(t *testing.T) {
 		t.Parallel()
 		t.Run("some stash entries", func(t *testing.T) {
