@@ -3,9 +3,8 @@ package gitdomain_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
-	"github.com/git-town/git-town/v17/test/git"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
 	"github.com/shoenig/test/must"
 )
 
@@ -64,6 +63,36 @@ func TestBranchInfos(t *testing.T) {
 		})
 	})
 
+	t.Run("FindByRemote", func(t *testing.T) {
+		t.Parallel()
+		t.Run("has a local branch with matching tracking branch", func(t *testing.T) {
+			t.Parallel()
+			branch := gitdomain.BranchInfo{
+				LocalName:  Some(gitdomain.NewLocalBranchName("two")),
+				LocalSHA:   Some(gitdomain.NewSHA("111111")),
+				SyncStatus: gitdomain.SyncStatusUpToDate,
+				RemoteName: Some(gitdomain.NewRemoteBranchName("origin/two")),
+				RemoteSHA:  Some(gitdomain.NewSHA("111111")),
+			}
+			bs := gitdomain.BranchInfos{branch}
+			have, has := bs.FindByRemoteName("origin/two").Get()
+			must.True(t, has)
+			must.Eq(t, &branch, have)
+		})
+		t.Run("has a local branch with the given name", func(t *testing.T) {
+			t.Parallel()
+			bs := gitdomain.BranchInfos{gitdomain.BranchInfo{
+				LocalName:  Some(gitdomain.NewLocalBranchName("kg/one")),
+				LocalSHA:   Some(gitdomain.NewSHA("111111")),
+				SyncStatus: gitdomain.SyncStatusLocalOnly,
+				RemoteName: None[gitdomain.RemoteBranchName](),
+				RemoteSHA:  None[gitdomain.SHA](),
+			}}
+			have := bs.FindByRemoteName("kg/one")
+			must.True(t, have.IsNone())
+		})
+	})
+
 	t.Run("FindLocalOrRemote", func(t *testing.T) {
 		t.Parallel()
 		t.Run("has local name", func(t *testing.T) {
@@ -79,7 +108,7 @@ func TestBranchInfos(t *testing.T) {
 			bis := gitdomain.BranchInfos{
 				branch1info,
 			}
-			have := bis.FindLocalOrRemote(branch1, git.RemoteOrigin)
+			have := bis.FindLocalOrRemote(branch1, gitdomain.RemoteOrigin)
 			must.Eq(t, MutableSome(&branch1info), have)
 		})
 		t.Run("has remote name", func(t *testing.T) {
@@ -94,7 +123,7 @@ func TestBranchInfos(t *testing.T) {
 			bis := gitdomain.BranchInfos{
 				branch1info,
 			}
-			have := bis.FindLocalOrRemote(gitdomain.NewLocalBranchName("branch-1"), git.RemoteOrigin)
+			have := bis.FindLocalOrRemote(gitdomain.NewLocalBranchName("branch-1"), gitdomain.RemoteOrigin)
 			must.Eq(t, MutableSome(&branch1info), have)
 		})
 		t.Run("no match", func(t *testing.T) {
@@ -109,7 +138,7 @@ func TestBranchInfos(t *testing.T) {
 			bis := gitdomain.BranchInfos{
 				branch1info,
 			}
-			have := bis.FindLocalOrRemote(gitdomain.NewLocalBranchName("zonk"), git.RemoteOrigin)
+			have := bis.FindLocalOrRemote(gitdomain.NewLocalBranchName("zonk"), gitdomain.RemoteOrigin)
 			must.Eq(t, MutableNone[gitdomain.BranchInfo](), have)
 		})
 	})
@@ -218,7 +247,7 @@ func TestBranchInfos(t *testing.T) {
 					RemoteSHA:  Some(gitdomain.NewSHA("111111")),
 				},
 			}
-			must.True(t, bs.HasMatchingTrackingBranchFor(gitdomain.NewLocalBranchName("one"), git.RemoteOrigin))
+			must.True(t, bs.HasMatchingTrackingBranchFor(gitdomain.NewLocalBranchName("one"), gitdomain.RemoteOrigin))
 		})
 		t.Run("has a remote-only branch with that name", func(t *testing.T) {
 			t.Parallel()
@@ -231,7 +260,7 @@ func TestBranchInfos(t *testing.T) {
 					RemoteSHA:  Some(gitdomain.NewSHA("111111")),
 				},
 			}
-			must.True(t, bs.HasMatchingTrackingBranchFor(gitdomain.NewLocalBranchName("one"), git.RemoteOrigin))
+			must.True(t, bs.HasMatchingTrackingBranchFor(gitdomain.NewLocalBranchName("one"), gitdomain.RemoteOrigin))
 		})
 		t.Run("has a local branch with a matching name", func(t *testing.T) {
 			t.Parallel()
@@ -244,7 +273,7 @@ func TestBranchInfos(t *testing.T) {
 					RemoteSHA:  None[gitdomain.SHA](),
 				},
 			}
-			must.False(t, bs.HasMatchingTrackingBranchFor(gitdomain.NewLocalBranchName("one"), git.RemoteOrigin))
+			must.False(t, bs.HasMatchingTrackingBranchFor(gitdomain.NewLocalBranchName("one"), gitdomain.RemoteOrigin))
 		})
 	})
 
@@ -382,36 +411,6 @@ func TestBranchInfos(t *testing.T) {
 		})
 	})
 
-	t.Run("FindByRemote", func(t *testing.T) {
-		t.Parallel()
-		t.Run("has a local branch with matching tracking branch", func(t *testing.T) {
-			t.Parallel()
-			branch := gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("two")),
-				LocalSHA:   Some(gitdomain.NewSHA("111111")),
-				SyncStatus: gitdomain.SyncStatusUpToDate,
-				RemoteName: Some(gitdomain.NewRemoteBranchName("origin/two")),
-				RemoteSHA:  Some(gitdomain.NewSHA("111111")),
-			}
-			bs := gitdomain.BranchInfos{branch}
-			have, has := bs.FindByRemoteName(gitdomain.NewRemoteBranchName("origin/two")).Get()
-			must.True(t, has)
-			must.Eq(t, &branch, have)
-		})
-		t.Run("has a local branch with the given name", func(t *testing.T) {
-			t.Parallel()
-			bs := gitdomain.BranchInfos{gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("kg/one")),
-				LocalSHA:   Some(gitdomain.NewSHA("111111")),
-				SyncStatus: gitdomain.SyncStatusLocalOnly,
-				RemoteName: None[gitdomain.RemoteBranchName](),
-				RemoteSHA:  None[gitdomain.SHA](),
-			}}
-			have := bs.FindByRemoteName(gitdomain.NewRemoteBranchName("kg/one"))
-			must.True(t, have.IsNone())
-		})
-	})
-
 	t.Run("Names", func(t *testing.T) {
 		t.Parallel()
 		bs := gitdomain.BranchInfos{
@@ -475,6 +474,59 @@ func TestBranchInfos(t *testing.T) {
 		})
 	})
 
+	t.Run("Select", func(t *testing.T) {
+		t.Parallel()
+		bs := gitdomain.BranchInfos{
+			gitdomain.BranchInfo{
+				LocalName:  Some(gitdomain.NewLocalBranchName("one")),
+				LocalSHA:   Some(gitdomain.NewSHA("111111")),
+				SyncStatus: gitdomain.SyncStatusLocalOnly,
+				RemoteName: None[gitdomain.RemoteBranchName](),
+				RemoteSHA:  None[gitdomain.SHA](),
+			},
+			gitdomain.BranchInfo{
+				LocalName:  Some(gitdomain.NewLocalBranchName("two")),
+				LocalSHA:   Some(gitdomain.NewSHA("111111")),
+				SyncStatus: gitdomain.SyncStatusLocalOnly,
+				RemoteName: None[gitdomain.RemoteBranchName](),
+				RemoteSHA:  None[gitdomain.SHA](),
+			},
+			gitdomain.BranchInfo{
+				LocalName:  Some(gitdomain.NewLocalBranchName("three")),
+				LocalSHA:   Some(gitdomain.NewSHA("111111")),
+				SyncStatus: gitdomain.SyncStatusLocalOnly,
+				RemoteName: None[gitdomain.RemoteBranchName](),
+				RemoteSHA:  None[gitdomain.SHA](),
+			},
+			gitdomain.BranchInfo{
+				LocalName:  Some(gitdomain.NewLocalBranchName("four")),
+				LocalSHA:   Some(gitdomain.NewSHA("111111")),
+				SyncStatus: gitdomain.SyncStatusLocalOnly,
+				RemoteName: None[gitdomain.RemoteBranchName](),
+				RemoteSHA:  None[gitdomain.SHA](),
+			},
+		}
+		have, nonExisting := bs.Select(gitdomain.RemoteOrigin, "one", "three")
+		want := gitdomain.BranchInfos{
+			gitdomain.BranchInfo{
+				LocalName:  Some(gitdomain.NewLocalBranchName("one")),
+				LocalSHA:   Some(gitdomain.NewSHA("111111")),
+				SyncStatus: gitdomain.SyncStatusLocalOnly,
+				RemoteName: None[gitdomain.RemoteBranchName](),
+				RemoteSHA:  None[gitdomain.SHA](),
+			},
+			gitdomain.BranchInfo{
+				LocalName:  Some(gitdomain.NewLocalBranchName("three")),
+				LocalSHA:   Some(gitdomain.NewSHA("111111")),
+				SyncStatus: gitdomain.SyncStatusLocalOnly,
+				RemoteName: None[gitdomain.RemoteBranchName](),
+				RemoteSHA:  None[gitdomain.SHA](),
+			},
+		}
+		must.Eq(t, want, have)
+		must.Eq(t, nonExisting, gitdomain.LocalBranchNames(nil))
+	})
+
 	t.Run("does not contain the removed element", func(t *testing.T) {
 		t.Parallel()
 		bs := gitdomain.BranchInfos{
@@ -512,57 +564,4 @@ func TestBranchInfos(t *testing.T) {
 		}
 		must.Eq(t, want, have)
 	})
-
-	t.Run("Select", func(t *testing.T) {
-		t.Parallel()
-		bs := gitdomain.BranchInfos{
-			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("one")),
-				LocalSHA:   Some(gitdomain.NewSHA("111111")),
-				SyncStatus: gitdomain.SyncStatusLocalOnly,
-				RemoteName: None[gitdomain.RemoteBranchName](),
-				RemoteSHA:  None[gitdomain.SHA](),
-			},
-			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("two")),
-				LocalSHA:   Some(gitdomain.NewSHA("111111")),
-				SyncStatus: gitdomain.SyncStatusLocalOnly,
-				RemoteName: None[gitdomain.RemoteBranchName](),
-				RemoteSHA:  None[gitdomain.SHA](),
-			},
-			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("three")),
-				LocalSHA:   Some(gitdomain.NewSHA("111111")),
-				SyncStatus: gitdomain.SyncStatusLocalOnly,
-				RemoteName: None[gitdomain.RemoteBranchName](),
-				RemoteSHA:  None[gitdomain.SHA](),
-			},
-			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("four")),
-				LocalSHA:   Some(gitdomain.NewSHA("111111")),
-				SyncStatus: gitdomain.SyncStatusLocalOnly,
-				RemoteName: None[gitdomain.RemoteBranchName](),
-				RemoteSHA:  None[gitdomain.SHA](),
-			},
-		}
-		have, nonExisting := bs.Select(git.RemoteOrigin, gitdomain.NewLocalBranchName("one"), gitdomain.NewLocalBranchName("three"))
-		want := gitdomain.BranchInfos{
-			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("one")),
-				LocalSHA:   Some(gitdomain.NewSHA("111111")),
-				SyncStatus: gitdomain.SyncStatusLocalOnly,
-				RemoteName: None[gitdomain.RemoteBranchName](),
-				RemoteSHA:  None[gitdomain.SHA](),
-			},
-			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("three")),
-				LocalSHA:   Some(gitdomain.NewSHA("111111")),
-				SyncStatus: gitdomain.SyncStatusLocalOnly,
-				RemoteName: None[gitdomain.RemoteBranchName](),
-				RemoteSHA:  None[gitdomain.SHA](),
-			},
-		}
-		must.Eq(t, want, have)
-		must.Eq(t, nonExisting, gitdomain.LocalBranchNames(nil))
-	})
 }
