@@ -3,8 +3,7 @@ package gitdomain_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/test/git"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
 	"github.com/shoenig/test/must"
 )
 
@@ -32,7 +31,7 @@ func TestLocalBranchNames(t *testing.T) {
 	t.Run("AtRemote", func(t *testing.T) {
 		t.Parallel()
 		branch := gitdomain.NewLocalBranchName("branch")
-		have := branch.AtRemote(git.RemoteOrigin)
+		have := branch.AtRemote(gitdomain.RemoteOrigin)
 		want := gitdomain.NewRemoteBranchName("origin/branch")
 		must.EqOp(t, want, have)
 	})
@@ -50,14 +49,14 @@ func TestLocalBranchNames(t *testing.T) {
 		t.Run("haystack contains needle", func(t *testing.T) {
 			t.Parallel()
 			branches := gitdomain.NewLocalBranchNames("one", "two", "three")
-			have := branches.Hoist(gitdomain.NewLocalBranchName("two"))
+			have := branches.Hoist("two")
 			want := gitdomain.NewLocalBranchNames("two", "one", "three")
 			must.Eq(t, want, have)
 		})
 		t.Run("haystack does not contain needle", func(t *testing.T) {
 			t.Parallel()
 			branches := gitdomain.NewLocalBranchNames("one", "two", "three")
-			have := branches.Hoist(gitdomain.NewLocalBranchName("zonk"))
+			have := branches.Hoist("zonk")
 			want := gitdomain.NewLocalBranchNames("one", "two", "three")
 			must.Eq(t, want, have)
 		})
@@ -146,14 +145,6 @@ func TestLocalBranchNames(t *testing.T) {
 		must.Eq(t, want, have)
 	})
 
-	t.Run("TrackingBranch", func(t *testing.T) {
-		t.Parallel()
-		branch := gitdomain.NewLocalBranchName("branch")
-		have := branch.TrackingBranch(git.RemoteOrigin)
-		want := gitdomain.NewRemoteBranchName("origin/branch")
-		must.EqOp(t, want, have)
-	})
-
 	t.Run("Sort", func(t *testing.T) {
 		t.Parallel()
 		branches := gitdomain.NewLocalBranchNames("one", "two", "three")
@@ -161,4 +152,12 @@ func TestLocalBranchNames(t *testing.T) {
 		branches.Sort()
 		must.Eq(t, want, branches.Strings())
 	})
+
+	t.Run("TrackingBranch", func(t *testing.T) {
+		t.Parallel()
+		branch := gitdomain.NewLocalBranchName("branch")
+		have := branch.TrackingBranch(gitdomain.RemoteOrigin)
+		want := gitdomain.NewRemoteBranchName("origin/branch")
+		must.EqOp(t, want, have)
+	})
 }
