@@ -3,25 +3,24 @@ package gitdomain_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/test/git"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
 	"github.com/shoenig/test/must"
 )
 
 func TestRemotes(t *testing.T) {
 	t.Parallel()
 
-	t.Run("HasOrigin", func(t *testing.T) {
+	t.Run("HasRemote", func(t *testing.T) {
 		t.Parallel()
 		t.Run("origin remote exists", func(t *testing.T) {
 			t.Parallel()
-			remotes := gitdomain.Remotes{git.RemoteOrigin}
-			must.True(t, remotes.Contains(git.RemoteOrigin))
+			remotes := gitdomain.Remotes{gitdomain.RemoteOrigin}
+			must.True(t, remotes.HasRemote(gitdomain.RemoteOrigin))
 		})
 		t.Run("origin remote does not exist", func(t *testing.T) {
 			t.Parallel()
 			remotes := gitdomain.Remotes{gitdomain.RemoteUpstream}
-			must.False(t, remotes.Contains(git.RemoteOrigin))
+			must.False(t, remotes.HasRemote(gitdomain.RemoteOrigin))
 		})
 	})
 
@@ -34,7 +33,7 @@ func TestRemotes(t *testing.T) {
 		})
 		t.Run("upstream remote does not exist", func(t *testing.T) {
 			t.Parallel()
-			remotes := gitdomain.Remotes{git.RemoteOrigin}
+			remotes := gitdomain.Remotes{gitdomain.RemoteOrigin}
 			must.False(t, remotes.HasUpstream())
 		})
 	})
