@@ -3,19 +3,20 @@ package slice_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/gohacks/slice"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/gohacks/slice"
 	"github.com/shoenig/test/must"
 )
 
 func TestAppendAllMissing(t *testing.T) {
 	t.Parallel()
 
-	t.Run("slice type", func(t *testing.T) {
+	t.Run("aliased slice type", func(t *testing.T) {
 		t.Parallel()
-		list := []string{"one", "two", "three"}
-		have := slice.AppendAllMissing(list, "two", "four", "five")
-		want := []string{"one", "two", "three", "four", "five"}
+		list := gitdomain.SHAs{"111111", "222222"}
+		give := gitdomain.SHAs{"333333", "444444"}
+		have := slice.AppendAllMissing(list, give...)
+		want := gitdomain.SHAs{"111111", "222222", "333333", "444444"}
 		must.Eq(t, want, have)
 	})
 
@@ -27,6 +28,14 @@ func TestAppendAllMissing(t *testing.T) {
 		must.Eq(t, want, have)
 	})
 
+	t.Run("slice type", func(t *testing.T) {
+		t.Parallel()
+		list := []string{"one", "two", "three"}
+		have := slice.AppendAllMissing(list, "two", "four", "five")
+		want := []string{"one", "two", "three", "four", "five"}
+		must.Eq(t, want, have)
+	})
+
 	t.Run("zero slice", func(t *testing.T) {
 		t.Parallel()
 		var list []string
@@ -34,13 +43,4 @@ func TestAppendAllMissing(t *testing.T) {
 		want := []string{"one", "two", "three"}
 		must.Eq(t, want, have)
 	})
-
-	t.Run("aliased slice type", func(t *testing.T) {
-		t.Parallel()
-		list := gitdomain.SHAs{gitdomain.NewSHA("111111"), gitdomain.NewSHA("222222")}
-		give := gitdomain.SHAs{gitdomain.NewSHA("333333"), gitdomain.NewSHA("444444")}
-		have := slice.AppendAllMissing(list, give...)
-		want := gitdomain.SHAs{gitdomain.NewSHA("111111"), gitdomain.NewSHA("222222"), gitdomain.NewSHA("333333"), gitdomain.NewSHA("444444")}
-		must.Eq(t, want, have)
-	})
 }
