@@ -3,14 +3,22 @@ package slice_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/gohacks/slice"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/gohacks/slice"
 	"github.com/shoenig/test/must"
 )
 
 func TestHoist(t *testing.T) {
 	t.Parallel()
 
+	t.Run("aliased slice type", func(t *testing.T) {
+		t.Parallel()
+		list := gitdomain.LocalBranchNames{"alpha", "initial", "omega"}
+		have := slice.Hoist(list, "initial")
+		want := gitdomain.LocalBranchNames{"initial", "alpha", "omega"}
+		must.Eq(t, want, have)
+	})
+
 	t.Run("already hoisted", func(t *testing.T) {
 		t.Parallel()
 		list := []string{"initial", "one", "two"}
@@ -33,12 +41,4 @@ func TestHoist(t *testing.T) {
 		have := slice.Hoist(list, "initial")
 		must.Len(t, 0, have)
 	})
-
-	t.Run("aliased slice type", func(t *testing.T) {
-		t.Parallel()
-		list := gitdomain.LocalBranchNames{gitdomain.NewLocalBranchName("alpha"), gitdomain.NewLocalBranchName("initial"), gitdomain.NewLocalBranchName("omega")}
-		have := slice.Hoist(list, gitdomain.NewLocalBranchName("initial"))
-		want := gitdomain.LocalBranchNames{gitdomain.NewLocalBranchName("initial"), gitdomain.NewLocalBranchName("alpha"), gitdomain.NewLocalBranchName("omega")}
-		must.Eq(t, want, have)
-	})
 }
