@@ -10,10 +10,13 @@ const (
 	APIUnexpectedResultDataStructure   = "unexpected result data structure"
 	APIUpdateProposalSource            = "Updating source branch of proposal %s to %s ... "
 	APIUpdateProposalTarget            = "Updating target branch of proposal %s to %s ... "
+	BitbucketAppPassword               = "Bitbucket app password: %s"
+	BitbucketUsername                  = "Bitbucket username: %s"
 	BranchAlreadyExistsLocally         = "there is already a branch %q"
 	BranchAlreadyExistsRemotely        = "there is already a branch %q at the \"origin\" remote"
 	BranchAuthorMultiple               = "\nMultiple people authored the %q branch.\n\n"
 	BranchCheckoutProblem              = "cannot check out branch %q: %w"
+	BranchContainsMergeCommits         = "branch %q contains merge commits, please compress and try again"
 	BranchCurrentProblem               = "cannot determine current branch: %w"
 	BranchDeleted                      = "deleted branch %q"
 	BranchDeletedAtRemote              = "branch %q was deleted at the remote"
@@ -34,7 +37,7 @@ const (
 	BranchParentChanged                = "branch %q is now a child of %q"
 	BrowserOpen                        = "Please open in a browser: %s\n"
 	CacheUnitialized                   = "using a cached value before initialization"
-	CodeHosting                        = "Code hosting: %s\n"
+	CodebergToken                      = "Codeberg token: %s\n"
 	CommandsRun                        = "Ran %d shell commands."
 	CommitMessageProblem               = "cannot determine last commit message: %w"
 	CommitsSelected                    = "%d commits selected"
@@ -71,6 +74,11 @@ const (
 	CreatePrototypeBranchesDeprecation = `The Git Town configuration file contains the deprecated setting "create-prototype-branches".
 Please upgrade to the new format: create.new-branch-type = "prototype"`
 	DefaultBranchType               = "Default branch type: %s\n"
+	DetachNeedsSync                 = "please sync this stack before detaching branches from it"
+	DetachNoParent                  = "cannot detach branches without parent"
+	DetachOtherWorkTree             = "cannot detach because branch %q it is active in another worktree"
+	DetachRemoteBranch              = "cannot detach a remote branch"
+	DetachUnsupportedBranchType     = "cannot detach %s branches since you don't own them"
 	DevRemote                       = "Development remote: %s\n"
 	DiffConflictWithMain            = "conflicts between your uncommmitted changes and the main branch"
 	DryRun                          = "In dry run mode. No commands will be run. When run in normal mode, the command output will appear beneath the command. Some commands will only be run if necessary. For example: 'git push' will run if and only if there are local commits not on origin."
@@ -90,6 +98,16 @@ Please upgrade to the new format: create.new-branch-type = "prototype"`
 	FileReadProblem                 = "cannot read file %q: %w"
 	FileStatProblem                 = "cannot check file %q: %w"
 	FileWriteProblem                = "cannot write file %q: %w"
+	Forge                           = "Forge: %s\n"
+	ForgeBitbucketNotImplemented    = "shipping pull requests via the Bitbucket API is currently not supported. If you need this functionality, please vote for it by opening a ticket at https://github.com/git-town/git-town/issues"
+	ForgeBitbucketMergingViaAPI     = "Bitbucket API: merging PR %s ... "
+	ForgeCodebergMergingViaAPI      = "Codeberg API: merging PR %s ... "
+	ForgeGitlabMergingViaAPI        = "Merging MR !%d ... "
+	ForgeGitlabUpdateMRViaAPI       = "Updating target branch for MR !%d to %q ... "
+	ForgeGiteaNotImplemented        = "shipping pull requests via the Gitea API is currently not supported. If you need this functionality, please vote for it by opening a ticket at https://github.com/git-town/git-town/issues"
+	ForgeGiteaUpdatePRViaAPI        = "Gitea API: Updating base branch for PR #%d to #%s"
+	ForgeGithubMergingViaAPI        = "GitHub API: merging PR %s ... "
+	ForgeTypeUnknown                = "unknown forge type: %q"
 	GiteaToken                      = "Gitea token: %s\n"
 	GitAnotherProcessIsRunningRetry = "another git process seems to be running in this repository, retrying in 1 sec ..."
 	GitHubEnterpriseInitializeError = "cannot initialize GitHub Enterprise client: %s"
@@ -119,14 +137,6 @@ END OUTPUT FROM 'git branch -vva'
 	HackBranchIsNowFeature              = "branch %q is now a feature branch\n"
 	HackCannotFeatureMainBranch         = "you are trying to convert the main branch to a feature branch. That's not possible. If you want to create a feature branch, did you forget to add the branch name?"
 	HackCannotFeaturePerennialBranch    = "branch %q is a perennial branch and cannot be a feature branch"
-	HostingBitbucketNotImplemented      = "shipping pull requests via the Bitbucket API is currently not supported. If you need this functionality, please vote for it by opening a ticket at https://github.com/git-town/git-town/issues"
-	HostingBitbucketMergingViaAPI       = "Bitbucket API: merging PR %s ... "
-	HostingGitlabMergingViaAPI          = "Merging MR !%d ... "
-	HostingGitlabUpdateMRViaAPI         = "Updating target branch for MR !%d to %q ... "
-	HostingGiteaNotImplemented          = "shipping pull requests via the Gitea API is currently not supported. If you need this functionality, please vote for it by opening a ticket at https://github.com/git-town/git-town/issues"
-	HostingGiteaUpdatePRViaAPI          = "Gitea API: Updating base branch for PR #%d to #%s"
-	HostingGithubMergingViaAPI          = "GitHub API: merging PR %s ... "
-	HostingPlatformUnknown              = "unknown hosting platform: %q"
 	InputAddOrRemove                    = `invalid argument %q. Please provide either "add" or "remove"`
 	InputYesOrNo                        = `invalid argument: %q. Please provide either "yes" or "no".\n`
 	DeleteCannotDeleteMainBranch        = "you cannot delete the main branch"
@@ -145,6 +155,8 @@ END OUTPUT FROM 'git branch -vva'
 	MergeOpenChanges                      = "please commit or remove the open changes first"
 	MergeNoGrandParent                    = "cannot merge branch %q because its parent branch (%s) has no parent"
 	MergeNoParent                         = "cannot merge branch %q because it has no parent"
+	MergeNotInSyncWithParent              = `branch %q is not in sync with its parent, please run "git town sync" and try again`
+	MergeNotInSyncWithTracking            = `branch %q is not in sync with its tracking branch, please run "git town sync" and try again`
 	MergeWrongBranchType                  = "cannot merge %s branches"
 	ObservedBranchCannotPark              = "cannot park observed branches"
 	ObservedBranchCannotPropose           = "cannot propose observed branches"
@@ -173,8 +185,8 @@ END OUTPUT FROM 'git branch -vva'
 	ProposalNoNumberGiven                 = "no proposal number given"
 	ProposalNoParent                      = "branch %q has no parent and can therefore not be proposed"
 	ProposalNotFoundForBranch             = "cannot determine proposal for branch %q: %w"
-	ProposalSourceCannotUpdate            = "cannot update the proposal source branch of your hosting platform"
-	ProposalTargetBranchUpdateProblem     = "cannot update the target branch of proposal %d via the API"
+	ProposalSourceCannotUpdate            = "cannot update the proposal source branch on your forge"
+	ProposalTargetBranchUpdateProblem     = "cannot update the target branch of proposal %d on your forge"
 	ProposalURLProblem                    = "cannot determine proposal URL from %q to %q: %w"
 	PrototypeBranchIsNowPrototype         = "branch %q is now a prototype branch\n"
 	PrototypeRemoved                      = "branch %q is no longer a prototype branch"
@@ -214,8 +226,8 @@ and will be removed in future versions of Git Town.`
 	ShipBranchIsInOtherWorktree             = "branch %q is checked out in another worktree, please ship from there"
 	ShipBranchNotInSync                     = "branch %q is not in sync"
 	ShipAbortedMergeError                   = "aborted because merge exited with error"
-	ShipAPIConnectorRequired                = "please configure API access to your hosting platform, more info at https://www.git-town.com/configuration#access-tokens"
-	ShipAPIConnectorUnsupported             = "the Git Town driver for your code hosting platform does not support shipping via the API"
+	ShipAPIConnectorRequired                = "please configure API access to your forge, more info at https://www.git-town.com/configuration#access-tokens"
+	ShipAPIConnectorUnsupported             = "the Git Town driver for your forge does not support shipping via the API"
 	ShipBranchOtherWorktree                 = "branch %q is active in another worktree"
 	ShipBranchHasNoParent                   = "branch %q has no parent to ship into"
 	ShipBranchNothingToDo                   = "the branch %q has no shippable changes"
@@ -239,6 +251,15 @@ and will be removed in future versions of Git Town.`
 	SquashCommitAuthorSelection             = "Selected squash commit author: %s\n"
 	SquashMessageProblem                    = "cannot comment out the squash commit message: %w"
 	StatusFileNotFound                      = "No status file found for this repository."
+	SwapNoGrandParent                       = "cannot swap a branch without grand-parent"
+	SwapNoParent                            = "cannot swap a branch without parent"
+	SwapNeedsCompress                       = "cannot swap because branch %q contains merge commits - please compress and try again"
+	SwapNeedsSync                           = "please sync your branches before swapping"
+	SwapOtherWorkTree                       = "cannot swap because branch %q it is active in another worktree"
+	SwapParentNotLocal                      = "cannot swap: parent branch %q is not available locally"
+	SwapParentWrongBranchType               = "cannot swap: branch %q is a %s branch"
+	SwapRemoteBranch                        = "cannot swap: branch %q is remote"
+	SwapUnsupportedBranchType               = "cannot swap: branch %q is a %s branch"
 	SwitchNoBranches                        = "no branches to switch to"
 	SwitchUncommittedChanges                = "uncommitted changes"
 	SyncFeatureBranches                     = "Sync feature branches: %s\n"
