@@ -1,14 +1,14 @@
 package undo
 
 import (
-	"github.com/git-town/git-town/v17/internal/cmd/cmdhelpers"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/undo/undobranches"
-	"github.com/git-town/git-town/v17/internal/undo/undoconfig"
-	"github.com/git-town/git-town/v17/internal/undo/undostash"
-	"github.com/git-town/git-town/v17/internal/vm/opcodes"
-	"github.com/git-town/git-town/v17/internal/vm/program"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
+	"github.com/git-town/git-town/v18/internal/cmd/cmdhelpers"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/undo/undobranches"
+	"github.com/git-town/git-town/v18/internal/undo/undoconfig"
+	"github.com/git-town/git-town/v18/internal/undo/undostash"
+	"github.com/git-town/git-town/v18/internal/vm/opcodes"
+	"github.com/git-town/git-town/v18/internal/vm/program"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
 )
 
 // creates the program for undoing a program that finished
@@ -21,11 +21,11 @@ func CreateUndoForFinishedProgram(args CreateUndoProgramArgs) program.Program {
 		result.Value.Add(&opcodes.ChangesStage{})
 		result.Value.Add(&opcodes.CommitWithMessage{
 			AuthorOverride: None[gitdomain.Author](),
-			Message:        gitdomain.CommitMessage("Committing open changes to undo them"),
+			Message:        "Committing open changes to undo them",
 		})
 	}
 	if endBranchesSnapshot, hasEndBranchesSnapshot := args.RunState.EndBranchesSnapshot.Get(); hasEndBranchesSnapshot {
-		result.Value.AddProgram(undobranches.DetermineUndoBranchesProgram(args.RunState.BeginBranchesSnapshot, endBranchesSnapshot, args.RunState.UndoablePerennialCommits, args.Config, args.RunState.TouchedBranches, args.RunState.UndoAPIProgram))
+		result.Value.AddProgram(undobranches.DetermineUndoBranchesProgram(args.RunState.BeginBranchesSnapshot, endBranchesSnapshot, args.RunState.UndoablePerennialCommits, args.Config, args.RunState.TouchedBranches, args.RunState.UndoAPIProgram, args.FinalMessages))
 	}
 	if endConfigSnapshot, hasEndConfigSnapshot := args.RunState.EndConfigSnapshot.Get(); hasEndConfigSnapshot {
 		result.Value.AddProgram(undoconfig.DetermineUndoConfigProgram(args.RunState.BeginConfigSnapshot, endConfigSnapshot))
