@@ -1,10 +1,7 @@
 package opcodes
 
 import (
-	"fmt"
-
 	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	"github.com/git-town/git-town/v18/internal/messages"
 	"github.com/git-town/git-town/v18/internal/vm/shared"
 )
 
@@ -23,15 +20,14 @@ func (self *BranchDeleteIfEmptyAtRuntime) Run(args shared.RunArgs) error {
 	if err != nil {
 		return err
 	}
-	if hasUnmergedChanges {
-		args.PrependOpcodes(&MessageQueue{
-			Message: fmt.Sprintf(messages.BranchDeletedHasUnmergedChanges, self.Branch),
-		})
-	} else {
+	if !hasUnmergedChanges {
 		args.PrependOpcodes(
 			&CheckoutParentOrMain{
 				Branch: self.Branch,
 			},
+			&BranchTrackingDelete{
+				Branch: self.Branch.TrackingBranch(args.Config.Value.NormalConfig.DevRemote),
+			},
 			&BranchLocalDeleteContent{
 				BranchToDelete:     self.Branch,
 				BranchToRebaseOnto: args.Config.Value.ValidatedConfigData.MainBranch,
