@@ -18,10 +18,10 @@ func (self *BranchLocalDeleteContent) Run(args shared.RunArgs) error {
 	switch args.Config.Value.NormalConfig.SyncFeatureStrategy {
 	case configdomain.SyncFeatureStrategyRebase:
 		args.PrependOpcodes(
-			&RebaseOnto{
-				BranchToRebaseAgainst: self.BranchToDelete.BranchName(),
-				BranchToRebaseOnto:    self.BranchToRebaseOnto,
-				Upstream:              None[gitdomain.LocalBranchName](),
+			&RebaseOntoRemoveDeleted{
+				BranchToRebaseOnto: self.BranchToRebaseOnto,
+				CommitsToRemove:    self.BranchToDelete.BranchName(),
+				Upstream:           None[gitdomain.LocalBranchName](),
 			},
 			&BranchLocalDelete{
 				Branch: self.BranchToDelete,
