@@ -3,14 +3,14 @@ package opcodes
 import (
 	"errors"
 
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/messages"
-	"github.com/git-town/git-town/v17/internal/vm/shared"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/messages"
+	"github.com/git-town/git-town/v18/internal/vm/shared"
 )
 
-// SquashMerge squash merges the branch with the given name into the current branch.
+// MergeFastForward fast-forwards the current branch to point to the commits on the given branch.
 type MergeFastForward struct {
-	Branch gitdomain.LocalBranchName
+	Branch gitdomain.BranchName
 	undeclaredOpcodeMethods
 }
 
