@@ -15,11 +15,11 @@ func (self *PushCurrentBranchForceIfNeeded) Run(args shared.RunArgs) error {
 	if err != nil {
 		return err
 	}
-	shouldPush, err := args.Git.ShouldPushBranch(args.Backend, currentBranch, args.Config.Value.NormalConfig.DevRemote)
+	inSync, err := args.Git.BranchInSyncWithTracking(args.Backend, currentBranch, args.Config.Value.NormalConfig.DevRemote)
 	if err != nil {
 		return err
 	}
-	if !shouldPush {
+	if inSync {
 		return nil
 	}
 	args.PrependOpcodes(&PushCurrentBranchForce{ForceIfIncludes: self.ForceIfIncludes})
