@@ -13,11 +13,17 @@ type PushCurrentBranchIfNeeded struct {
 }
 
 func (self *PushCurrentBranchIfNeeded) Run(args shared.RunArgs) error {
-	shouldPush, err := args.Git.ShouldPushBranch(args.Backend, self.CurrentBranch, args.Config.Value.NormalConfig.DevRemote)
+	// check if branch still exists
+	// the branch could not exist at this point if it was pruned at runtime due to being empty
+	branchExists := args.Git.BranchExists(args.Backend, self.CurrentBranch)
+	if !branchExists {
+		return nil
+	}
+	inSync, err := args.Git.BranchInSyncWithTracking(args.Backend, self.CurrentBranch, args.Config.Value.NormalConfig.DevRemote)
 	if err != nil {
 		return err
 	}
-	if !shouldPush {
+	if inSync {
 		return nil
 	}
 	args.PrependOpcodes(&PushCurrentBranch{})
