@@ -8,5 +8,5 @@ type PushTags struct {
 }
 
 func (self *PushTags) Run(args shared.RunArgs) error {
-	return args.Git.PushTags(args.Frontend)
+	return args.Git.PushTags(args.Frontend, args.Config.Value.NormalConfig.NoPushHook())
 }
