@@ -21,16 +21,16 @@ func (self *RebaseTrackingBranch) Run(args shared.RunArgs) error {
 			// The force-push succeeded --> the remote branch didn't contain new commits, we are done.
 			return nil
 		}
-		// Here the force-push failed --> the remote branch contains new commits.
-		// We need to integrate them into the local branch.
+		// Here the force-push failed. Possible causes:
+		// a) the remote branch contains new commits
+		// b) the branch is currently in a GitHub Merge Queue and doesn't accept pushes
+		// To be sure, we pull in updates from the tracking branch and try the force-push again.
+		// We ignore the error of the second force-push because of (b).
 		args.PrependOpcodes(
 			// Rebase the local commits against the remote commits.
 			&RebaseBranch{Branch: self.RemoteBranch.BranchName()},
-			// Now try force-pushing again.
-			&RebaseTrackingBranch{
-				PushBranches: self.PushBranches,
-				RemoteBranch: self.RemoteBranch,
-			},
+			// Now try force-pushing again, once, and ignore the error.
+			&PushCurrentBranchForceIgnoreError{},
 		)
 	} else {
 		args.PrependOpcodes(&RebaseBranch{Branch: self.RemoteBranch.BranchName()})
