@@ -1,10 +1,8 @@
 package opcodes
 
 import (
-	"errors"
-
-	"github.com/git-town/git-town/v17/internal/messages"
-	"github.com/git-town/git-town/v17/internal/vm/shared"
+	"github.com/git-town/git-town/v18/internal/messages"
+	"github.com/git-town/git-town/v18/internal/vm/shared"
 )
 
 // restores stashed away changes into the workspace
@@ -19,7 +17,7 @@ func (self *StashPop) ContinueProgram() []shared.Opcode {
 func (self *StashPop) Run(args shared.RunArgs) error {
 	err := args.Git.PopStash(args.Frontend)
 	if err != nil {
-		return errors.New(messages.DiffConflictWithMain)
+		args.FinalMessages.Add(messages.DiffConflictWithMain)
 	}
 	return nil
 }
