@@ -3,10 +3,10 @@ package shared
 import (
 	"github.com/git-town/git-town/v18/internal/cli/dialog/components"
 	"github.com/git-town/git-town/v18/internal/config"
+	"github.com/git-town/git-town/v18/internal/forge/forgedomain"
 	"github.com/git-town/git-town/v18/internal/git"
 	"github.com/git-town/git-town/v18/internal/git/gitdomain"
 	"github.com/git-town/git-town/v18/internal/gohacks/stringslice"
-	"github.com/git-town/git-town/v18/internal/hosting/hostingdomain"
 	. "github.com/git-town/git-town/v18/pkg/prelude"
 )
 
@@ -14,7 +14,7 @@ type RunArgs struct {
 	Backend                         gitdomain.RunnerQuerier
 	BranchInfos                     Option[gitdomain.BranchInfos]
 	Config                          Mutable[config.ValidatedConfig]
-	Connector                       Option[hostingdomain.Connector]
+	Connector                       Option[forgedomain.Connector]
 	DialogTestInputs                components.TestInputs
 	FinalMessages                   stringslice.Collector
 	Frontend                        gitdomain.Runner
