@@ -52,7 +52,6 @@ func TestLoadSave(t *testing.T) {
 				&opcodes.BranchCurrentResetToParent{CurrentBranch: "branch"},
 				&opcodes.BranchCurrentResetToSHA{Hard: true, SetToSHA: "111111"},
 				&opcodes.BranchCurrentResetToSHAIfNeeded{Hard: true, MustHaveSHA: "222222", SetToSHA: "111111"},
-				&opcodes.BranchDeleteIfEmptyAtRuntime{Branch: "branch"},
 				&opcodes.BranchEnsureShippableChanges{Branch: "branch", Parent: "parent"},
 				&opcodes.BranchLocalDelete{Branch: "branch"},
 				&opcodes.BranchLocalDeleteContent{BranchToDelete: "branch", BranchToRebaseOnto: "main"},
@@ -65,6 +64,7 @@ func TestLoadSave(t *testing.T) {
 				&opcodes.BranchTrackingDelete{Branch: "origin/branch"},
 				&opcodes.BranchTypeOverrideSet{Branch: "branch", BranchType: configdomain.BranchTypeFeatureBranch},
 				&opcodes.BranchTypeOverrideRemove{Branch: "branch"},
+				&opcodes.BranchWithRemoteGoneDeleteIfEmptyAtRuntime{Branch: "branch"},
 				&opcodes.ChangesDiscard{},
 				&opcodes.ChangesStage{},
 				&opcodes.ChangesUnstageAll{},
@@ -108,6 +108,7 @@ func TestLoadSave(t *testing.T) {
 				&opcodes.PushCurrentBranch{},
 				&opcodes.PushCurrentBranchForce{ForceIfIncludes: true},
 				&opcodes.PushCurrentBranchForceIfNeeded{ForceIfIncludes: true},
+				&opcodes.PushCurrentBranchForceIgnoreError{},
 				&opcodes.PushCurrentBranchIfLocal{CurrentBranch: "branch"},
 				&opcodes.PushCurrentBranchIfNeeded{CurrentBranch: "branch"},
 				&opcodes.PushTags{},
@@ -115,9 +116,10 @@ func TestLoadSave(t *testing.T) {
 				&opcodes.RebaseBranch{Branch: "branch"},
 				&opcodes.RebaseContinue{},
 				&opcodes.RebaseContinueIfNeeded{},
-				&opcodes.RebaseOnto{BranchToRebaseAgainst: "branch-1", BranchToRebaseOnto: "branch-2", Upstream: Some(gitdomain.NewLocalBranchName("upstream"))},
+				&opcodes.RebaseOntoKeepDeleted{BranchToRebaseOnto: "branch-2", CommitsToRemove: "branch-1"},
+				&opcodes.RebaseOntoRemoveDeleted{BranchToRebaseOnto: "branch-2", CommitsToRemove: "branch-1", Upstream: Some(gitdomain.NewLocalBranchName("upstream"))},
 				&opcodes.RebaseParentIfNeeded{Branch: "branch"},
-				&opcodes.RebaseTrackingBranch{RemoteBranch: "origin/branch"},
+				&opcodes.RebaseTrackingBranch{RemoteBranch: "origin/branch", PushBranches: true},
 				&opcodes.RegisterUndoablePerennialCommit{Parent: "parent"},
 				&opcodes.SnapshotInitialUpdateLocalSHA{Branch: "branch", SHA: "111111"},
 				&opcodes.SnapshotInitialUpdateLocalSHAIfNeeded{Branch: "branch"},
@@ -133,6 +135,8 @@ func TestLoadSave(t *testing.T) {
 				EndTime:   time.Time{},
 			}),
 			UndoablePerennialCommits: []gitdomain.SHA{},
+			FinalUndoProgram:         program.Program{},
+			UndoAPIProgram:           program.Program{},
 		}
 
 		wantJSON := `
@@ -199,12 +203,6 @@ func TestLoadSave(t *testing.T) {
       },
       "type": "BranchCurrentResetToSHAIfNeeded"
     },
-    {
-      "data": {
-        "Branch": "branch"
-      },
-      "type": "BranchDeleteIfEmptyAtRuntime"
-    },
     {
       "data": {
         "Branch": "branch",
@@ -285,6 +283,12 @@ func TestLoadSave(t *testing.T) {
       },
       "type": "BranchTypeOverrideRemove"
     },
+    {
+      "data": {
+        "Branch": "branch"
+      },
+      "type": "BranchWithRemoteGoneDeleteIfEmptyAtRuntime"
+    },
     {
       "data": {},
       "type": "ChangesDiscard"
@@ -563,6 +567,10 @@ func TestLoadSave(t *testing.T) {
       },
       "type": "PushCurrentBranchForceIfNeeded"
     },
+    {
+      "data": {},
+      "type": "PushCurrentBranchForceIgnoreError"
+    },
     {
       "data": {
         "CurrentBranch": "branch"
@@ -599,11 +607,19 @@ func TestLoadSave(t *testing.T) {
     },
     {
       "data": {
-        "BranchToRebaseAgainst": "branch-1",
         "BranchToRebaseOnto": "branch-2",
+        "CommitsToRemove": "branch-1",
+        "Upstream": null
+      },
+      "type": "RebaseOntoKeepDeleted"
+    },
+    {
+      "data": {
+        "BranchToRebaseOnto": "branch-2",
+        "CommitsToRemove": "branch-1",
         "Upstream": "upstream"
       },
-      "type": "RebaseOnto"
+      "type": "RebaseOntoRemoveDeleted"
     },
     {
       "data": {
@@ -613,7 +629,7 @@ func TestLoadSave(t *testing.T) {
     },
     {
       "data": {
-        "PushBranches": false,
+        "PushBranches": true,
         "RemoteBranch": "origin/branch"
       },
       "type": "RebaseTrackingBranch"
