@@ -7,6 +7,7 @@ import (
 	"os"
 	"os/exec"
 	"path/filepath"
+	"reflect"
 	"regexp"
 	"strings"
 	"time"
@@ -18,8 +19,8 @@ import (
 	"github.com/git-town/git-town/v18/internal/cli/print"
 	"github.com/git-town/git-town/v18/internal/config/configdomain"
 	"github.com/git-town/git-town/v18/internal/config/configfile"
+	"github.com/git-town/git-town/v18/internal/forge/forgedomain"
 	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	"github.com/git-town/git-town/v18/internal/hosting/hostingdomain"
 	. "github.com/git-town/git-town/v18/pkg/prelude"
 	"github.com/git-town/git-town/v18/test/asserts"
 	"github.com/git-town/git-town/v18/test/commands"
@@ -230,6 +231,17 @@ func defineSteps(sc *godog.ScenarioContext) {
 		devRepo.CreateFile(name, content)
 	})
 
+	sc.Step(`^an uncommitted file with name "([^"]+)" exists now$`, func(ctx context.Context, filename string) error {
+		state := ctx.Value(keyScenarioState).(*ScenarioState)
+		devRepo := state.fixture.DevRepo.GetOrPanic()
+		files := devRepo.UncommittedFiles()
+		want := []string{filename}
+		if !reflect.DeepEqual(files, want) {
+			return fmt.Errorf("expected %s but found %s", want, files)
+		}
+		return nil
+	})
+
 	sc.Step(`^an upstream repo$`, func(ctx context.Context) {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		state.fixture.AddUpstream()
@@ -238,7 +250,7 @@ func defineSteps(sc *godog.ScenarioContext) {
 	sc.Step(`^a proposal for this branch does not exist`, func(ctx context.Context) {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		devRepo := state.fixture.DevRepo.GetOrPanic()
-		devRepo.TestRunner.ProposalOverride = Some(hostingdomain.OverrideNoProposal)
+		devRepo.TestRunner.ProposalOverride = Some(forgedomain.OverrideNoProposal)
 	})
 
 	sc.Step(`^a proposal for this branch exists at "([^"]+)"`, func(ctx context.Context, url string) {
@@ -514,6 +526,13 @@ func defineSteps(sc *godog.ScenarioContext) {
 		return nil
 	})
 
+	sc.Step(`^I add an unrelated stash entry with file "([^"]+)"$`, func(ctx context.Context, filename string) {
+		state := ctx.Value(keyScenarioState).(*ScenarioState)
+		devRepo := state.fixture.DevRepo.GetOrPanic()
+		devRepo.CreateFile(filename, "stash content")
+		devRepo.StashOpenFiles()
+	})
+
 	sc.Step(`^I add commit "([^"]*)" to the "([^"]*)" branch$`, func(ctx context.Context, message, branch string) {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		devRepo := state.fixture.DevRepo.GetOrPanic()
@@ -541,6 +560,20 @@ func defineSteps(sc *godog.ScenarioContext) {
 		devRepo.CommitStagedChanges(commit.Message)
 	})
 
+	sc.Step(`^I amend this commit$`, func(ctx context.Context, table *godog.Table) error {
+		state := ctx.Value(keyScenarioState).(*ScenarioState)
+		devRepo := state.fixture.DevRepo.GetOrPanic()
+		commits := testgit.FromGherkinTable(table)
+		if len(commits) != 1 {
+			return errors.New("expected exactly one commit")
+		}
+		commit := commits[0]
+		devRepo.CheckoutBranch(commit.Branch)
+		devRepo.CreateFile(commit.FileName, commit.FileContent)
+		asserts.NoError(devRepo.Run("git", "add", commit.FileName))
+		return devRepo.Run("git", "commit", "--amend", "--message", commit.Message.String())
+	})
+
 	sc.Step(`^I am not prompted for any parent branches$`, func(ctx context.Context) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		notExpected := "Please specify the parent branch of"
@@ -781,18 +814,6 @@ func defineSteps(sc *godog.ScenarioContext) {
 		devRepo.Reload()
 	})
 
-	sc.Step(`^"([^"]*)" launches a new proposal with this url in my browser:$`, func(ctx context.Context, tool string, url *godog.DocString) error {
-		state := ctx.Value(keyScenarioState).(*ScenarioState)
-		want := fmt.Sprintf("%s called with: %s", tool, url.Content)
-		want = strings.ReplaceAll(want, "?", `\?`)
-		regex := regexp.MustCompile(want)
-		have := state.runOutput.GetOrPanic()
-		if !regex.MatchString(have) {
-			return fmt.Errorf("EXPECTED: a regex matching %q\nGOT: %q", want, have)
-		}
-		return nil
-	})
-
 	sc.Step(`^my repo's "([^"]*)" remote is "([^"]*)"$`, func(ctx context.Context, remoteName, remoteURL string) {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		devRepo := state.fixture.DevRepo.GetOrPanic()
@@ -1015,21 +1036,8 @@ func defineSteps(sc *godog.ScenarioContext) {
 
 	sc.Step(`^the commits$`, func(ctx context.Context, table *godog.Table) {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
-		devRepo := state.fixture.DevRepo.GetOrPanic()
-		// create the commits
 		commits := testgit.FromGherkinTable(table)
 		state.fixture.CreateCommits(commits)
-		// restore the initial branch
-		initialBranch, hasInitialBranch := state.initialCurrentBranch.Get()
-		if !hasInitialBranch {
-			devRepo.CheckoutBranch("main")
-			return
-		}
-		// NOTE: reading the cached value here to keep the test suite fast by avoiding unnecessary disk access
-		if devRepo.CurrentBranchCache.Value() != initialBranch {
-			devRepo.CheckoutBranch(initialBranch)
-			return
-		}
 	})
 
 	sc.Step(`^the committed configuration file:$`, func(ctx context.Context, content *godog.DocString) {
