@@ -3,20 +3,19 @@ package datatable_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/test/datatable"
-	"github.com/git-town/git-town/v17/test/git"
+	"github.com/git-town/git-town/v18/test/datatable"
+	"github.com/git-town/git-town/v18/test/testgit"
 	"github.com/shoenig/test/must"
 )
 
 func TestCommitTableBuilder(t *testing.T) {
 	t.Parallel()
 	builder := datatable.NewCommitTableBuilder()
-	commit1 := git.Commit{SHA: gitdomain.NewSHA("111111"), Branch: gitdomain.NewLocalBranchName("branch1"), Message: "commit1"}
-	commit2 := git.Commit{SHA: gitdomain.NewSHA("222222"), Branch: gitdomain.NewLocalBranchName("main"), Message: "commit2"}
-	commit3 := git.Commit{SHA: gitdomain.NewSHA("333333"), Branch: gitdomain.NewLocalBranchName("main"), Message: "commit3"}
-	commit4 := git.Commit{SHA: gitdomain.NewSHA("444444"), Branch: gitdomain.NewLocalBranchName("branch2"), Message: "commit4"}
-	commit5 := git.Commit{SHA: gitdomain.NewSHA("555555"), Branch: gitdomain.NewLocalBranchName("branch3"), Message: "commit5"}
+	commit1 := testgit.Commit{SHA: "111111", Branch: "branch1", Message: "commit1"}
+	commit2 := testgit.Commit{SHA: "222222", Branch: "main", Message: "commit2"}
+	commit3 := testgit.Commit{SHA: "333333", Branch: "main", Message: "commit3"}
+	commit4 := testgit.Commit{SHA: "444444", Branch: "branch2", Message: "commit4"}
+	commit5 := testgit.Commit{SHA: "555555", Branch: "branch3", Message: "commit5"}
 	builder.Add(commit1, "local")
 	builder.Add(commit1, "origin")
 	builder.Add(commit1, "worktree")
